Class: SignwellSDK::Models::RateLimitErrorResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/signwell_sdk/models/rate_limit_error_response.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(error:) ⇒ Object

Rate limit exceeded error response (HTTP 429)

Parameters:

  • error (String)

    Rate limit error message indicating the limit and reset time



# File 'lib/signwell_sdk/models/rate_limit_error_response.rb', line 12

Instance Attribute Details

#errorString

Rate limit error message indicating the limit and reset time

Returns:

  • (String)


10
# File 'lib/signwell_sdk/models/rate_limit_error_response.rb', line 10

required :error, String