Class: SignwellSDK::Models::V1::BulkSendCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/signwell_sdk/models/v1/bulk_send_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(bulk_send_csv:, template_ids:, api_application_id: nil, apply_signing_order: nil, custom_requester_email: nil, custom_requester_name: nil, message: nil, name: nil, skip_row_errors: nil, subject: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see SignwellSDK::Models::V1::BulkSendCreateParams for more details.

Parameters:

  • bulk_send_csv (String)

    A RFC 4648 base64 string of the template CSV file to be validated.

  • template_ids (Array<String>)

    Unique identifiers for a list of templates.

  • api_application_id (String) (defaults to: nil)

    Unique identifier for API Application settings to use. API Applications are opti

  • apply_signing_order (Boolean) (defaults to: nil)

    When set to ‘true` recipients will sign one at a time in the order of the `recip

  • custom_requester_email (String) (defaults to: nil)

    Sets the custom requester email for the document. When set, this is the email us

  • custom_requester_name (String) (defaults to: nil)

    Sets the custom requester name for the document. When set, this is the name used

  • message (String) (defaults to: nil)

    Email message for the signature request that recipients will see. Defaults to th

  • name (String) (defaults to: nil)

    The name of the Bulk Send. Will be used as the document name for each of the doc

  • skip_row_errors (Boolean) (defaults to: nil)

    Whether to skip errors in the rows. Defaults to ‘false`.

  • subject (String) (defaults to: nil)

    Email subject for the signature request that recipients will see. Defaults to th

  • request_options (SignwellSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/signwell_sdk/models/v1/bulk_send_create_params.rb', line 79

Instance Attribute Details

#api_application_idString?

Unique identifier for API Application settings to use. API Applications are optional and mainly used when isolating OAuth apps or for more control over embedded API settings

Returns:

  • (String, nil)


29
# File 'lib/signwell_sdk/models/v1/bulk_send_create_params.rb', line 29

optional :api_application_id, String

#apply_signing_orderBoolean?

When set to ‘true` recipients will sign one at a time in the order of the `recipients` collection of this request.

Returns:

  • (Boolean, nil)


36
# File 'lib/signwell_sdk/models/v1/bulk_send_create_params.rb', line 36

optional :apply_signing_order, SignwellSDK::Internal::Type::Boolean

#bulk_send_csvString

A RFC 4648 base64 string of the template CSV file to be validated.

Returns:

  • (String)


15
# File 'lib/signwell_sdk/models/v1/bulk_send_create_params.rb', line 15

required :bulk_send_csv, String

#custom_requester_emailString?

Sets the custom requester email for the document. When set, this is the email used for all email communications, signing notifications, and in the audit file.

Returns:

  • (String, nil)


43
# File 'lib/signwell_sdk/models/v1/bulk_send_create_params.rb', line 43

optional :custom_requester_email, String

#custom_requester_nameString?

Sets the custom requester name for the document. When set, this is the name used for all email communications, signing notifications, and in the audit file.

Returns:

  • (String, nil)


50
# File 'lib/signwell_sdk/models/v1/bulk_send_create_params.rb', line 50

optional :custom_requester_name, String

#messageString?

Email message for the signature request that recipients will see. Defaults to the default system message or a template message.

Returns:

  • (String, nil)


57
# File 'lib/signwell_sdk/models/v1/bulk_send_create_params.rb', line 57

optional :message, String

#nameString?

The name of the Bulk Send. Will be used as the document name for each of the documents.

Returns:

  • (String, nil)


64
# File 'lib/signwell_sdk/models/v1/bulk_send_create_params.rb', line 64

optional :name, String

#skip_row_errorsBoolean?

Whether to skip errors in the rows. Defaults to ‘false`.

Returns:

  • (Boolean, nil)


70
# File 'lib/signwell_sdk/models/v1/bulk_send_create_params.rb', line 70

optional :skip_row_errors, SignwellSDK::Internal::Type::Boolean

#subjectString?

Email subject for the signature request that recipients will see. Defaults to the default system subject or a template subject.

Returns:

  • (String, nil)


77
# File 'lib/signwell_sdk/models/v1/bulk_send_create_params.rb', line 77

optional :subject, String

#template_idsArray<String>

Unique identifiers for a list of templates.

Returns:

  • (Array<String>)


21
# File 'lib/signwell_sdk/models/v1/bulk_send_create_params.rb', line 21

required :template_ids, SignwellSDK::Internal::Type::ArrayOf[String]