Class: SignwellSDK::Models::V1::BulkSendListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/signwell_sdk/models/v1/bulk_send_list_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(api_application_id: nil, limit: nil, page: nil, user_email: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see SignwellSDK::Models::V1::BulkSendListParams for more details.

Parameters:

  • api_application_id (String) (defaults to: nil)

    Unique identifier for API Application settings to use. API Applications are opti

  • limit (Integer) (defaults to: nil)

    The number of documents to fetch. Defaults to 10, max is 50.

  • page (Integer) (defaults to: nil)

    The page number for pagination. Defaults to the first page.

  • user_email (String) (defaults to: nil)

    The email address of the user that sent the Bulk Send. Must have the ‘admin` or

  • request_options (SignwellSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/signwell_sdk/models/v1/bulk_send_list_params.rb', line 39

Instance Attribute Details

#api_application_idString?

Unique identifier for API Application settings to use. API Applications are optional and mainly used when isolating OAuth apps or for more control over embedded API settings

Returns:

  • (String, nil)


17
# File 'lib/signwell_sdk/models/v1/bulk_send_list_params.rb', line 17

optional :api_application_id, String

#limitInteger?

The number of documents to fetch. Defaults to 10, max is 50.

Returns:

  • (Integer, nil)


23
# File 'lib/signwell_sdk/models/v1/bulk_send_list_params.rb', line 23

optional :limit, Integer

#pageInteger?

The page number for pagination. Defaults to the first page.

Returns:

  • (Integer, nil)


29
# File 'lib/signwell_sdk/models/v1/bulk_send_list_params.rb', line 29

optional :page, Integer

#user_emailString?

The email address of the user that sent the Bulk Send. Must have the ‘admin` or `manager` role to view Bulk Sends of other users. Defaults to the user that the API key belongs to.

Returns:

  • (String, nil)


37
# File 'lib/signwell_sdk/models/v1/bulk_send_list_params.rb', line 37

optional :user_email, String