Class: SignwellSDK::Models::V1::CheckboxGroup

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/signwell_sdk/models/v1/checkbox_group.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(checkbox_ids:, group_name:, recipient_id:, exact_value: nil, max_value: nil, min_value: nil, required: nil, validation: nil) ⇒ Object

Some parameter documentations has been truncated, see SignwellSDK::Models::V1::CheckboxGroup for more details.

Parameters:

  • checkbox_ids (Array<String>)
  • group_name (String)

    A unique identifier for the checkbox group.

  • recipient_id (String)

    The recipient ID associated with the checkbox group.

  • exact_value (Integer) (defaults to: nil)

    The exact number of checkboxes that must be checked in the group. (Only for vali

  • max_value (Integer) (defaults to: nil)

    The maximum number of checkboxes that can be checked in the group. (Only for val

  • min_value (Integer) (defaults to: nil)

    The minimum number of checkboxes that must be checked in the group. (Only for va

  • required (Boolean) (defaults to: nil)

    Whether the group must be completed by the recipient. Defaults to false.

  • validation (Symbol, SignwellSDK::Models::CheckboxValidation) (defaults to: nil)

    Set requirements for the group of one or multiple selections by the recipient. D



# File 'lib/signwell_sdk/models/v1/checkbox_group.rb', line 58

Instance Attribute Details

#checkbox_idsArray<String>

Returns:

  • (Array<String>)


10
# File 'lib/signwell_sdk/models/v1/checkbox_group.rb', line 10

required :checkbox_ids, SignwellSDK::Internal::Type::ArrayOf[String]

#exact_valueInteger?

The exact number of checkboxes that must be checked in the group. (Only for validation: exact)

Returns:

  • (Integer, nil)


29
# File 'lib/signwell_sdk/models/v1/checkbox_group.rb', line 29

optional :exact_value, Integer

#group_nameString

A unique identifier for the checkbox group.

Returns:

  • (String)


16
# File 'lib/signwell_sdk/models/v1/checkbox_group.rb', line 16

required :group_name, String

#max_valueInteger?

The maximum number of checkboxes that can be checked in the group. (Only for validation: maximum and range)

Returns:

  • (Integer, nil)


36
# File 'lib/signwell_sdk/models/v1/checkbox_group.rb', line 36

optional :max_value, Integer

#min_valueInteger?

The minimum number of checkboxes that must be checked in the group. (Only for validation: minimum and range)

Returns:

  • (Integer, nil)


43
# File 'lib/signwell_sdk/models/v1/checkbox_group.rb', line 43

optional :min_value, Integer

#recipient_idString

The recipient ID associated with the checkbox group.

Returns:

  • (String)


22
# File 'lib/signwell_sdk/models/v1/checkbox_group.rb', line 22

required :recipient_id, String

#requiredBoolean?

Whether the group must be completed by the recipient. Defaults to false.

Returns:

  • (Boolean, nil)


49
# File 'lib/signwell_sdk/models/v1/checkbox_group.rb', line 49

optional :required, SignwellSDK::Internal::Type::Boolean

#validationSymbol, ...

Set requirements for the group of one or multiple selections by the recipient. Defaults to minimum. Validation values: minimum, maximum, exact, range.

Returns:



56
# File 'lib/signwell_sdk/models/v1/checkbox_group.rb', line 56

optional :validation, enum: -> { SignwellSDK::CheckboxValidation }