Class: SignwellSDK::Models::V1::DocumentCreateFromTemplateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/signwell_sdk/models/v1/document_create_from_template_params.rb

Overview

Defined Under Namespace

Classes: Field, File, Recipient, TemplateField

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:, file_base64: nil, file_url: nil) ⇒ Object

Additional files to be appended to the document. Will not replace existing files from the template. Document files can be uploaded by specifying a file URL or base64 string. Either ‘file_url` or `file_base64` must be present (not both). Valid file types are: .pdf, .docx, .jpg, .png, .ppt, .xls, .pages, and .txt.

Parameters:

  • name (String)

    Name of the file that will be uploaded.

  • file_base64 (String) (defaults to: nil)

    A RFC 4648 base64 string of the file to be uploaded.

  • file_url (String) (defaults to: nil)

    Publicly available URL of the file to be uploaded.



# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 385

Instance Attribute Details

#allow_declineBoolean?

Whether to allow recipients the option to decline signing a document. If multiple signers are involved in a document, any single recipient can cancel the entire document signing process by declining to sign.

Returns:

  • (Boolean, nil)


26
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 26

optional :allow_decline, SignwellSDK::Internal::Type::Boolean

#allow_reassignBoolean?

In some cases a signer is not the right person to sign and may need to reassign their signing responsibilities to another person. This feature allows them to reassign the document to someone else.

Returns:

  • (Boolean, nil)


34
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 34

optional :allow_reassign, SignwellSDK::Internal::Type::Boolean

#api_application_idString?

Unique identifier for API Application settings to use. API Applications are optional and mainly used when isolating OAuth apps or for more control over embedded API settings

Returns:

  • (String, nil)


42
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 42

optional :api_application_id, String

#apply_signing_orderBoolean?

When set to ‘true` recipients will sign one at a time in the order of the `recipients` collection of this request.

Returns:

  • (Boolean, nil)


49
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 49

optional :apply_signing_order, SignwellSDK::Internal::Type::Boolean

#attachment_requestsArray<SignwellSDK::Models::V1::AttachmentRequest>?

Attachments that a recipient must upload to complete the signing process. Attachment requests are shown after all document fields have been completed.



56
57
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 56

optional :attachment_requests,
-> { SignwellSDK::Internal::Type::ArrayOf[SignwellSDK::V1::AttachmentRequest] }

#checkbox_groupsArray<SignwellSDK::Models::V1::CheckboxGroup>?

Checkbox fields that are placed on a document can be grouped with selection requirements. At least 2 checkbox fields in an array of fields must be assigned to the same recipient.



65
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 65

optional :checkbox_groups, -> { SignwellSDK::Internal::Type::ArrayOf[SignwellSDK::V1::CheckboxGroup] }

#copied_contactsArray<SignwellSDK::Models::V1::CopiedContact>?

Copied contacts are emailed the final document once it has been completed by all recipients.



72
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 72

optional :copied_contacts, -> { SignwellSDK::Internal::Type::ArrayOf[SignwellSDK::V1::CopiedContact] }

#custom_requester_emailString?

Sets the custom requester email for the document. When set, this is the email used for all email communications, signing notifications, and in the audit file.

Returns:

  • (String, nil)


79
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 79

optional :custom_requester_email, String

#custom_requester_nameString?

Sets the custom requester name for the document. When set, this is the name used for all email communications, signing notifications, and in the audit file.

Returns:

  • (String, nil)


86
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 86

optional :custom_requester_name, String

#decline_redirect_urlString?

A URL that recipients are redirected to if the document is declined.

Returns:

  • (String, nil)


92
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 92

optional :decline_redirect_url, String

#draftBoolean?

Whether the document can still be updated before sending a signature request. If set to ‘false` the document is sent for signing as part of this request. Defaults to `false`.

Returns:

  • (Boolean, nil)


100
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 100

optional :draft, SignwellSDK::Internal::Type::Boolean

#embedded_signingBoolean?

When set to ‘true` it enables embedded signing in your website/web application. Embedded functionality works with an iFrame and email authentication is disabled. :embedded_signinig defaults to `false`.

Returns:

  • (Boolean, nil)


108
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 108

optional :embedded_signing, SignwellSDK::Internal::Type::Boolean

#embedded_signing_notificationsBoolean?

On embedding signing, document owners (and CC’d contacts) do not get a notification email when documents have been completed. Setting this param to ‘true` will send out those final completed notifications. Default is `false`

Returns:

  • (Boolean, nil)


116
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 116

optional :embedded_signing_notifications, SignwellSDK::Internal::Type::Boolean

#expires_inInteger?

Number of days before the signature request expires. Defaults to the account expiration setting or template expiration (if the document is created from a template).

Returns:

  • (Integer, nil)


124
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 124

optional :expires_in, Integer

#fieldsArray<Array<SignwellSDK::Models::V1::DocumentCreateFromTemplateParams::Field>>?

Fields to be added to any appended files (not existing files). Document fields placed on a document for collecting data or signatures from recipients. Field data should be sent as a 2-dimensional JSON array. One array of fields is needed for each file in the files array. An array of fields can be empty if you have a file that does not contain any fields.



134
135
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 134

optional :fields,
-> { SignwellSDK::Internal::Type::ArrayOf[SignwellSDK::Internal::Type::ArrayOf[SignwellSDK::V1::DocumentCreateFromTemplateParams::Field]] }

#filesArray<SignwellSDK::Models::V1::DocumentCreateFromTemplateParams::File>?



140
141
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 140

optional :files,
-> { SignwellSDK::Internal::Type::ArrayOf[SignwellSDK::V1::DocumentCreateFromTemplateParams::File] }

#labelsArray<SignwellSDK::Models::V1::Label>?

Labels can be used to organize documents in a way that can make it easy to find using the document search in SignWell. A document can have multiple labels. Updating labels on a document will replace any existing labels for that document.

Returns:



150
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 150

optional :labels, -> { SignwellSDK::Internal::Type::ArrayOf[SignwellSDK::V1::Label] }

#languageString?

Sets the language for all recipients on the document and updates all recipient side interactions including the document email and the document itself. Accepted languages: English, Français, Español, Deutsch, Polski, Português, Dansk, Nederlands, Italiano, Русский, Svenska, العربية, Ελληνικά, Türkçe, Slovenčina. Defaults to English. Language should be sent in ISO 639-1 format: en, fr, es, de, pl, pt, da, nl, it, ru, sv, ar, el, tr, sk.

Returns:

  • (String, nil)


161
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 161

optional :language, String

#messageString?

Email message for the signature request that recipients will see. Defaults to the default system message or a template message (if the document is created from a template).

Returns:

  • (String, nil)


169
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 169

optional :message, String

#metadataHash{Symbol=>String}?

Optional key-value data that can be associated with the document. If set, will be available every time the document data is returned.

Returns:

  • (Hash{Symbol=>String}, nil)


176
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 176

optional :metadata, SignwellSDK::Internal::Type::HashOf[String]

#nameString?

The name of the document.

Returns:

  • (String, nil)


182
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 182

optional :name, String

#recipientsArray<SignwellSDK::Models::V1::DocumentCreateFromTemplateParams::Recipient>

Document recipients are people that must complete and/or sign a document. Recipients of the document must be assigned to a placeholder of the template. Recipients will inherit all placeholder fields and settings.



17
18
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 17

required :recipients,
-> { SignwellSDK::Internal::Type::ArrayOf[SignwellSDK::V1::DocumentCreateFromTemplateParams::Recipient] }

#redirect_urlString?

A URL that recipients are redirected to after successfully signing a document.

Returns:

  • (String, nil)


188
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 188

optional :redirect_url, String

#remindersBoolean?

Whether to send signing reminders to recipients. Reminders are sent on day 3, day 6, and day 10 if set to ‘true`. Defaults to `true`.

Returns:

  • (Boolean, nil)


195
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 195

optional :reminders, SignwellSDK::Internal::Type::Boolean

#subjectString?

Email subject for the signature request that recipients will see. Defaults to the default system subject or a template subject (if the document is created from a template).

Returns:

  • (String, nil)


203
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 203

optional :subject, String

#template_fieldsArray<SignwellSDK::Models::V1::DocumentCreateFromTemplateParams::TemplateField>?

Fields of your template(s) that you can prepopulate with values. Signature and Initials fields cannot be signed through the API.



210
211
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 210

optional :template_fields,
-> { SignwellSDK::Internal::Type::ArrayOf[SignwellSDK::V1::DocumentCreateFromTemplateParams::TemplateField] }

#template_idString?

Use when you have to create a document from a single template. Either :template_id or :template_ids must be present in the request, not both.

Returns:

  • (String, nil)


218
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 218

optional :template_id, String

#template_idsArray<String>?

Use when you have to create a document from multiple templates. Either :template_id or :template_ids must be present in the request, not both.

Returns:

  • (Array<String>, nil)


225
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 225

optional :template_ids, SignwellSDK::Internal::Type::ArrayOf[String]

#test_modeBoolean?

Set to ‘true` to enable Test Mode. Documents created with Test Mode do not count towards API billing and are not legally binding. Defaults to `false`

Returns:

  • (Boolean, nil)


232
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 232

optional :test_mode, SignwellSDK::Internal::Type::Boolean

#text_tagsBoolean?

An alternative way (if you can’t use the recommended way) of placing fields in specific locations of your document by using special text tags. Useful when changing the content of your files changes the location of fields. See API documentation for “Text Tags” for details. Defaults to false.

Returns:

  • (Boolean, nil)


241
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 241

optional :text_tags, SignwellSDK::Internal::Type::Boolean

#with_signature_pageBoolean?

When set to ‘true` the document will have a signature page added to the end, and all signers will be required to add their signature on that page.

Returns:

  • (Boolean, nil)


248
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 248

optional :with_signature_page, SignwellSDK::Internal::Type::Boolean

Class Method Details

.variantsArray(String, Boolean, Float)

Returns:

  • (Array(String, Boolean, Float))


# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 666