Class: SignwellSDK::Models::V1::DocumentCreateFromTemplateParams::Field
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SignwellSDK::Models::V1::DocumentCreateFromTemplateParams::Field
- Defined in:
- lib/signwell_sdk/models/v1/document_create_from_template_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#allow_other ⇒ Boolean?
Whether to allow “Other” option with text input (for dropdown/select fields only).
-
#api_id ⇒ String?
Unique identifier of the field.
-
#date_format ⇒ Symbol, ...
Date fields only: date format to use for the field.
-
#default_option ⇒ String?
Default selected option (for dropdown/select fields only).
-
#fixed_width ⇒ Boolean?
Text fields only: whether the field width will stay fixed and text will display in multiple lines, rather than one long line.
-
#formula ⇒ String?
Date fields only (text field formulas coming soon): formulas are a way to prefill fields with calculated future or past dates.
-
#height ⇒ Float?
Height of the field (in pixels).
-
#label ⇒ String?
Text and Date fields only: label that is displayed when the field is empty.
-
#lock_sign_date ⇒ Boolean?
Date fields only: makes fields readonly and automatically populates with the date the recipient signed.
-
#name ⇒ String?
Checkbox fields only.
-
#options ⇒ Array<String, SignwellSDK::Models::V1::DocumentCreateFromTemplateParams::Field::Option::DetailedOption>?
Array of dropdown options (for dropdown/select fields only).
-
#page ⇒ Integer
The page number within the file.
-
#recipient_id ⇒ String
Unique identifier of the recipient assigned to the field.
-
#required ⇒ Boolean?
Whether the field must be completed by the recipient.
-
#type ⇒ Symbol, SignwellSDK::Models::FieldType
Field type of the field.
-
#validation ⇒ Symbol, ...
Text fields only: optional validation for field values.
-
#value ⇒ String, ...
Varies according to the field type.
-
#width ⇒ Float?
Width of the field (in pixels).
-
#x ⇒ Float
Horizontal value in the coordinates of the field (in pixels).
-
#y_ ⇒ Float
Vertical value in the coordinates of the field (in pixels).
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(name:, api_id: nil, is_other: nil) ⇒ Object
constructor
Detailed option object.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:, api_id: nil, is_other: nil) ⇒ Object
Detailed option object
|
|
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 562
|
Instance Attribute Details
#allow_other ⇒ Boolean?
Whether to allow “Other” option with text input (for dropdown/select fields only)
452 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 452 optional :allow_other, SignwellSDK::Internal::Type::Boolean |
#api_id ⇒ String?
Unique identifier of the field. Useful when needing to reference specific field values or update a document and its fields.
459 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 459 optional :api_id, String |
#date_format ⇒ Symbol, ...
Date fields only: date format to use for the field. Valid values: MM/DD/YYYY, DD/MM/YYYY, YYYY/MM/DD, Month DD, YYYY, and MM/DD/YYYY hh:mm:ss a. Defaults to MM/DD/YYYY.
467 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 467 optional :date_format, enum: -> { SignwellSDK::DateFormat } |
#default_option ⇒ String?
Default selected option (for dropdown/select fields only)
473 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 473 optional :default_option, String |
#fixed_width ⇒ Boolean?
Text fields only: whether the field width will stay fixed and text will display in multiple lines, rather than one long line. If set to ‘false` the field width will automatically grow horizontally to fit text on one line. Defaults to `false`.
482 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 482 optional :fixed_width, SignwellSDK::Internal::Type::Boolean |
#formula ⇒ String?
Date fields only (text field formulas coming soon): formulas are a way to prefill fields with calculated future or past dates. Addition, subtraction, and parentheses are allowed. Valid event dates are ‘created_date`, `sent_date`, and `signed_date`. Valid time periods are `day`, `days`, `week`, `weeks`, `month`, and `months`. Example: `formula: ’sent_date + 10 days’‘. Use with `lock_sign_date` if you’d like to make the field readonly and prevent signers from choosing a different date.
494 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 494 optional :formula, String |
#height ⇒ Float?
Height of the field (in pixels). Maximum height varies by field type: Signature/Initials (200px), others (74px). When using text tags if the height is greater than the maximum height, the height will be set to the maximum height.
502 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 502 optional :height, Float |
#label ⇒ String?
Text and Date fields only: label that is displayed when the field is empty.
508 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 508 optional :label, String |
#lock_sign_date ⇒ Boolean?
Date fields only: makes fields readonly and automatically populates with the date the recipient signed. Defaults to ‘false`.
515 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 515 optional :lock_sign_date, SignwellSDK::Internal::Type::Boolean |
#name ⇒ String?
Checkbox fields only. At least 2 checkbox fields in an array of fields must be assigned to the same recipient and grouped with selection requirements.
522 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 522 optional :name, String |
#options ⇒ Array<String, SignwellSDK::Models::V1::DocumentCreateFromTemplateParams::Field::Option::DetailedOption>?
Array of dropdown options (for dropdown/select fields only)
528 529 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 528 optional :options, -> { SignwellSDK::Internal::Type::ArrayOf[union: SignwellSDK::V1::DocumentCreateFromTemplateParams::Field::Option] } |
#page ⇒ Integer
The page number within the file. If the page does not exist within the file then the field won’t be created.
415 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 415 required :page, Integer |
#recipient_id ⇒ String
Unique identifier of the recipient assigned to the field. Recipients assigned to fields will be the only ones that will see and be able to complete those fields.
422 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 422 required :recipient_id, String |
#required ⇒ Boolean?
Whether the field must be completed by the recipient. Defaults to ‘true` except for checkbox type fields.
536 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 536 optional :required, SignwellSDK::Internal::Type::Boolean |
#type ⇒ Symbol, SignwellSDK::Models::FieldType
Field type of the field. Valid field types: initials, signatures, checkbox, date, and text. To autofill fields with contact data, use an autofill field type. To group checkbox fields, enter an api_id for each checkbox and add the checkbox_groups parameter.
431 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 431 required :type, enum: -> { SignwellSDK::FieldType } |
#validation ⇒ Symbol, ...
Text fields only: optional validation for field values. Valid values: numbers, letters, email_address, us_phone_number, us_zip_code, us_ssn, us_age, alphanumeric, us_bank_routing_number, us_bank_account.
544 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 544 optional :validation, enum: -> { SignwellSDK::TextValidation } |
#value ⇒ String, ...
Varies according to the field type. Text fields accept strings or numbers. Date fields accept Iso8601 date strings. CheckBoxes accept booleans. Signature and Initials fields can’t be signed through API requests. Autofill text fields accept strings or numbers.
553 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 553 optional :value, union: -> { SignwellSDK::V1::DocumentCreateFromTemplateParams::Field::Value } |
#width ⇒ Float?
Width of the field (in pixels). For text fields, width will auto-grow unless ‘fixed_width` is true.
560 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 560 optional :width, Float |
#x ⇒ Float
Horizontal value in the coordinates of the field (in pixels). Coordinates are specific to the page where fields are located.
438 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 438 required :x, Float |
#y_ ⇒ Float
Vertical value in the coordinates of the field (in pixels). Coordinates are specific to the page where fields are located.
445 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 445 required :y_, Float, api_name: :y |
Class Method Details
.variants ⇒ Array(String, SignwellSDK::Models::V1::DocumentCreateFromTemplateParams::Field::Option::DetailedOption)
|
|
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 647
|