Class: SignwellSDK::Models::V1::DocumentCreateFromTemplateParams::Recipient

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/signwell_sdk/models/v1/document_create_from_template_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(recipients:, allow_decline: nil, allow_reassign: nil, api_application_id: nil, apply_signing_order: nil, attachment_requests: nil, checkbox_groups: nil, copied_contacts: nil, custom_requester_email: nil, custom_requester_name: nil, decline_redirect_url: nil, draft: nil, embedded_signing: nil, embedded_signing_notifications: nil, expires_in: nil, fields: nil, files: nil, labels: nil, language: nil, message: nil, metadata: nil, name: nil, redirect_url: nil, reminders: nil, subject: nil, template_fields: nil, template_id: nil, template_ids: nil, test_mode: nil, text_tags: nil, with_signature_page: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see SignwellSDK::Models::V1::DocumentCreateFromTemplateParams for more details.

:template_

Parameters:

  • recipients (Array<SignwellSDK::Models::V1::DocumentCreateFromTemplateParams::Recipient>)

    Document recipients are people that must complete and/or sign a document. Recipi

  • allow_decline (Boolean) (defaults to: nil)

    Whether to allow recipients the option to decline signing a document. If multipl

  • allow_reassign (Boolean) (defaults to: nil)

    In some cases a signer is not the right person to sign and may need to reassign

  • api_application_id (String) (defaults to: nil)

    Unique identifier for API Application settings to use. API Applications are opti

  • apply_signing_order (Boolean) (defaults to: nil)

    When set to ‘true` recipients will sign one at a time in the order of the `recip

  • attachment_requests (Array<SignwellSDK::Models::V1::AttachmentRequest>) (defaults to: nil)

    Attachments that a recipient must upload to complete the signing process. Attach

  • checkbox_groups (Array<SignwellSDK::Models::V1::CheckboxGroup>) (defaults to: nil)

    Checkbox fields that are placed on a document can be grouped with selection requ

  • copied_contacts (Array<SignwellSDK::Models::V1::CopiedContact>) (defaults to: nil)

    Copied contacts are emailed the final document once it has been completed by all

  • custom_requester_email (String) (defaults to: nil)

    Sets the custom requester email for the document. When set, this is the email us

  • custom_requester_name (String) (defaults to: nil)

    Sets the custom requester name for the document. When set, this is the name used

  • decline_redirect_url (String) (defaults to: nil)

    A URL that recipients are redirected to if the document is declined.

  • draft (Boolean) (defaults to: nil)

    Whether the document can still be updated before sending a signature request. If

  • embedded_signing (Boolean) (defaults to: nil)

    When set to ‘true` it enables embedded signing in your website/web application.

  • embedded_signing_notifications (Boolean) (defaults to: nil)

    On embedding signing, document owners (and CC’d contacts) do not get a notificat

  • expires_in (Integer) (defaults to: nil)

    Number of days before the signature request expires. Defaults to the account exp

  • fields (Array<Array<SignwellSDK::Models::V1::DocumentCreateFromTemplateParams::Field>>) (defaults to: nil)

    Fields to be added to any appended files (not existing files). Document fields p

  • files (Array<SignwellSDK::Models::V1::DocumentCreateFromTemplateParams::File>) (defaults to: nil)
  • labels (Array<SignwellSDK::Models::V1::Label>) (defaults to: nil)

    Labels can be used to organize documents in a way that can make it easy to find

  • language (String) (defaults to: nil)

    Sets the language for all recipients on the document and updates all recipient s

  • message (String) (defaults to: nil)

    Email message for the signature request that recipients will see. Defaults to th

  • metadata (Hash{Symbol=>String}) (defaults to: nil)

    Optional key-value data that can be associated with the document. If set, will b

  • name (String) (defaults to: nil)

    The name of the document.

  • redirect_url (String) (defaults to: nil)

    A URL that recipients are redirected to after successfully signing a document.

  • reminders (Boolean) (defaults to: nil)

    Whether to send signing reminders to recipients. Reminders are sent on day 3, da

  • subject (String) (defaults to: nil)

    Email subject for the signature request that recipients will see. Defaults to th

  • template_fields (Array<SignwellSDK::Models::V1::DocumentCreateFromTemplateParams::TemplateField>) (defaults to: nil)

    Fields of your template(s) that you can prepopulate with values. Signature and I

  • template_id (String) (defaults to: nil)

    Use when you have to create a document from a single template. Either

  • template_ids (Array<String>) (defaults to: nil)

    Use when you have to create a document from multiple templates. Either :template

  • test_mode (Boolean) (defaults to: nil)

    Set to ‘true` to enable Test Mode. Documents created with Test Mode do not count

  • text_tags (Boolean) (defaults to: nil)

    An alternative way (if you can’t use the recommended way) of placing fields in s

  • with_signature_page (Boolean) (defaults to: nil)

    When set to ‘true` the document will have a signature page added to the end, and

  • request_options (SignwellSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 319

class Recipient < SignwellSDK::Internal::Type::BaseModel
  # @!attribute id
  #   A unique identifier that you will give to each recipient. We recommend numbering
  #   sequentially from 1 to X. IDs are required for associating recipients to fields
  #   and more.
  #
  #   @return [String]
  required :id, String

  # @!attribute email
  #   Email address for the recipient.
  #
  #   @return [String]
  required :email, String

  # @!attribute message
  #   Email message for the signature request that the recipient will see. Overrides
  #   the general message for the template.
  #
  #   @return [String, nil]
  optional :message, String

  # @!attribute name
  #   Name of the recipient.
  #
  #   @return [String, nil]
  optional :name, String

  # @!attribute passcode
  #   If set, signers assigned with a passcode will be required to enter the passcode
  #   before they’re able to view and complete the document.
  #
  #   @return [String, nil]
  optional :passcode, String

  # @!attribute placeholder_name
  #   The name of the placeholder you want this recipient assigned to.
  #
  #   @return [String, nil]
  optional :placeholder_name, String

  # @!attribute send_email
  #   Applies on when `embedded_signing` is `true`. By default, recipients are not
  #   notified through email to sign when doing embedded signing. Setting this to
  #   `true` will send a notification email to the recipient. Default is `false`.
  #
  #   @return [Boolean, nil]
  optional :send_email, SignwellSDK::Internal::Type::Boolean

  # @!attribute send_email_delay
  #   If `send_email` is `true` recipients will receive a new document notification
  #   immediately. In the case of embedded signing, you can delay this notification to
  #   only send if the document is not completed within a few minutes. The email
  #   notification will not go out if the document is completed before the delay time
  #   is over. Valid values are in minutes ranging from `0` to `60`. Defaults to `0`.
  #
  #   @return [Integer, nil]
  optional :send_email_delay, Integer

  # @!attribute subject
  #   Email subject for the signature request that the recipient will see. Overrides
  #   the general subject for the template.
  #
  #   @return [String, nil]
  optional :subject, String

  # @!method initialize(id:, email:, message: nil, name: nil, passcode: nil, placeholder_name: nil, send_email: nil, send_email_delay: nil, subject: nil)
  #   Some parameter documentations has been truncated, see
  #   {SignwellSDK::Models::V1::DocumentCreateFromTemplateParams::Recipient} for more
  #   details.
  #
  #   @param id [String] A unique identifier that you will give to each recipient. We recommend numbering
  #
  #   @param email [String] Email address for the recipient.
  #
  #   @param message [String] Email message for the signature request that the recipient will see. Overrides t
  #
  #   @param name [String] Name of the recipient.
  #
  #   @param passcode [String] If set, signers assigned with a passcode will be required to enter the passcode
  #
  #   @param placeholder_name [String] The name of the placeholder you want this recipient assigned to.
  #
  #   @param send_email [Boolean] Applies on when `embedded_signing` is `true`. By default, recipients are not not
  #
  #   @param send_email_delay [Integer] If `send_email` is `true` recipients will receive a new document notification im
  #
  #   @param subject [String] Email subject for the signature request that the recipient will see. Overrides t
end

Instance Attribute Details

#emailString

Email address for the recipient.

Returns:

  • (String)


332
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 332

required :email, String

#idString

A unique identifier that you will give to each recipient. We recommend numbering sequentially from 1 to X. IDs are required for associating recipients to fields and more.

Returns:

  • (String)


326
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 326

required :id, String

#messageString?

Email message for the signature request that the recipient will see. Overrides the general message for the template.

Returns:

  • (String, nil)


339
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 339

optional :message, String

#nameString?

Name of the recipient.

Returns:

  • (String, nil)


345
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 345

optional :name, String

#passcodeString?

If set, signers assigned with a passcode will be required to enter the passcode before they’re able to view and complete the document.

Returns:

  • (String, nil)


352
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 352

optional :passcode, String

#placeholder_nameString?

The name of the placeholder you want this recipient assigned to.

Returns:

  • (String, nil)


358
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 358

optional :placeholder_name, String

#send_emailBoolean?

Applies on when ‘embedded_signing` is `true`. By default, recipients are not notified through email to sign when doing embedded signing. Setting this to `true` will send a notification email to the recipient. Default is `false`.

Returns:

  • (Boolean, nil)


366
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 366

optional :send_email, SignwellSDK::Internal::Type::Boolean

#send_email_delayInteger?

If ‘send_email` is `true` recipients will receive a new document notification immediately. In the case of embedded signing, you can delay this notification to only send if the document is not completed within a few minutes. The email notification will not go out if the document is completed before the delay time is over. Valid values are in minutes ranging from `0` to `60`. Defaults to `0`.

Returns:

  • (Integer, nil)


376
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 376

optional :send_email_delay, Integer

#subjectString?

Email subject for the signature request that the recipient will see. Overrides the general subject for the template.

Returns:

  • (String, nil)


383
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 383

optional :subject, String