Class: SignwellSDK::Models::V1::DocumentCreateFromTemplateParams::TemplateField

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/signwell_sdk/models/v1/document_create_from_template_params.rb

Defined Under Namespace

Modules: Value

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(api_id:, value:) ⇒ Object

Parameters:

  • api_id (String)

    The API ID of the field in your template. This field is case sensitive.

  • value (String, Boolean, Float)

    TextField value must be a string or a number.



# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 716

Instance Attribute Details

#api_idString

The API ID of the field in your template. This field is case sensitive.

Returns:

  • (String)


708
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 708

required :api_id, String

#valueString, ...

TextField value must be a string or a number.

Returns:

  • (String, Boolean, Float)


714
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 714

required :value, union: -> { SignwellSDK::V1::DocumentCreateFromTemplateParams::TemplateField::Value }