Class: SignwellSDK::Models::V1::DocumentRetrieveCompletedPdfParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/signwell_sdk/models/v1/document_retrieve_completed_pdf_params.rb

Overview

Defined Under Namespace

Modules: FileFormat

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(audit_page: nil, file_format: nil, url_only: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see SignwellSDK::Models::V1::DocumentRetrieveCompletedPdfParams for more details.

Parameters:

  • audit_page (Boolean) (defaults to: nil)

    Whether to include the audit page as part of the document. Defaults to ‘true`

  • file_format (Symbol, SignwellSDK::Models::V1::DocumentRetrieveCompletedPdfParams::FileFormat) (defaults to: nil)

    Format of the file to be downloaded. Supported formats are ‘pdf’ and ‘zip’.

  • url_only (Boolean) (defaults to: nil)

    Whether to return the URL of the completed PDF or the actual PDF content. Defaul

  • request_options (SignwellSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/signwell_sdk/models/v1/document_retrieve_completed_pdf_params.rb', line 30

Instance Attribute Details

#audit_pageBoolean?

Whether to include the audit page as part of the document. Defaults to ‘true`

Returns:

  • (Boolean, nil)


15
# File 'lib/signwell_sdk/models/v1/document_retrieve_completed_pdf_params.rb', line 15

optional :audit_page, SignwellSDK::Internal::Type::Boolean

#file_formatSymbol, ...

Format of the file to be downloaded. Supported formats are ‘pdf’ and ‘zip’.



21
# File 'lib/signwell_sdk/models/v1/document_retrieve_completed_pdf_params.rb', line 21

optional :file_format, enum: -> { SignwellSDK::V1::DocumentRetrieveCompletedPdfParams::FileFormat }

#url_onlyBoolean?

Whether to return the URL of the completed PDF or the actual PDF content. Defaults to ‘false`.

Returns:

  • (Boolean, nil)


28
# File 'lib/signwell_sdk/models/v1/document_retrieve_completed_pdf_params.rb', line 28

optional :url_only, SignwellSDK::Internal::Type::Boolean