Class: SignwellSDK::Models::V1::DocumentTemplateCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/signwell_sdk/models/v1/document_template_create_params.rb

Overview

Defined Under Namespace

Classes: AttachmentRequest, CopiedPlaceholder, Field, Placeholder

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:, preassigned_recipient_email: nil, preassigned_recipient_name: nil) ⇒ Object

Some parameter documentations has been truncated, see CopiedPlaceholder for more details.

Parameters:

  • name (String)

    Name of the placeholder.

  • preassigned_recipient_email (String) (defaults to: nil)

    In some cases, it may be necessary to pre-fill the name and email for a placehol

  • preassigned_recipient_name (String) (defaults to: nil)

    In some cases, it may be necessary to pre-fill the name and email for a placehol



# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 270

Instance Attribute Details

#allow_declineBoolean?

Whether to allow recipients the option to decline signing a document. If multiple signers are involved in a document, any single recipient can cancel the entire document signing process by declining to sign.

Returns:

  • (Boolean, nil)


36
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 36

optional :allow_decline, SignwellSDK::Internal::Type::Boolean

#allow_reassignBoolean?

In some cases a signer is not the right person to sign and may need to reassign their signing responsibilities to another person. This feature allows them to reassign the document to someone else.

Returns:

  • (Boolean, nil)


44
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 44

optional :allow_reassign, SignwellSDK::Internal::Type::Boolean

#api_application_idString?

Unique identifier for API Application settings to use. API Applications are optional and mainly used when isolating OAuth apps or for more control over embedded API settings

Returns:

  • (String, nil)


52
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 52

optional :api_application_id, String

#apply_signing_orderBoolean?

When set to ‘true` recipients will sign one at a time in the order of the `recipients` collection of this request.

Returns:

  • (Boolean, nil)


59
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 59

optional :apply_signing_order, SignwellSDK::Internal::Type::Boolean

#attachment_requestsArray<SignwellSDK::Models::V1::DocumentTemplateCreateParams::AttachmentRequest>?

Attachments that a recipient must upload to complete the signing process. Attachment requests are shown after all document fields have been completed.



66
67
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 66

optional :attachment_requests,
-> { SignwellSDK::Internal::Type::ArrayOf[SignwellSDK::V1::DocumentTemplateCreateParams::AttachmentRequest] }

#checkbox_groupsArray<SignwellSDK::Models::V1::TemplateCheckboxGroup>?

Checkbox fields that are placed on a document can be grouped with selection requirements. At least 2 checkbox fields in an array of fields must be assigned to the same recipient.



75
76
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 75

optional :checkbox_groups,
-> { SignwellSDK::Internal::Type::ArrayOf[SignwellSDK::V1::TemplateCheckboxGroup] }

#copied_placeholdersArray<SignwellSDK::Models::V1::DocumentTemplateCreateParams::CopiedPlaceholder>?

Copied placeholders are emailed the final document once it has been completed by all recipients.



83
84
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 83

optional :copied_placeholders,
-> { SignwellSDK::Internal::Type::ArrayOf[SignwellSDK::V1::DocumentTemplateCreateParams::CopiedPlaceholder] }

#decline_redirect_urlString?

A URL that recipients are redirected to if the document is declined.

Returns:

  • (String, nil)


90
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 90

optional :decline_redirect_url, String

#draftBoolean?

Whether the template can still be updated before it is ready for usage. If set to ‘false` the template is marked as `Available` and it will be ready for use. Defaults to `false`.

Returns:

  • (Boolean, nil)


98
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 98

optional :draft, SignwellSDK::Internal::Type::Boolean

#expires_inInteger?

Number of days before the signature request expires. Defaults to the account expiration setting or template expiration (if the document is created from a template).

Returns:

  • (Integer, nil)


106
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 106

optional :expires_in, Integer

#fieldsArray<Array<SignwellSDK::Models::V1::DocumentTemplateCreateParams::Field>>?

Document fields placed on a document for collecting data or signatures from recipients. At least one field must be present in the Create Document request if ‘draft` is `false` (unless adding a signature page by using `with_signature_page`). Field data should be sent as a 2-dimensional JSON array. One array of fields is needed for each file in the files array. An array of fields can be empty if you have a file that does not contain any fields.



117
118
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 117

optional :fields,
-> { SignwellSDK::Internal::Type::ArrayOf[SignwellSDK::Internal::Type::ArrayOf[SignwellSDK::V1::DocumentTemplateCreateParams::Field]] }

#filesArray<SignwellSDK::Models::V1::DocumentFile>

Document files can be uploaded by specifying a file URL or base64 string. Either ‘file_url` or `file_base64` must be present (not both). Valid file types are: .pdf, .doc, .docx, .pages, .ppt, .pptx, .key, .xls, .xlsx, .numbers, .jpg, .jpeg, .png, .tiff, .tif, .webp, .html, and .htm



18
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 18

required :files, -> { SignwellSDK::Internal::Type::ArrayOf[SignwellSDK::V1::DocumentFile] }

#labelsArray<SignwellSDK::Models::V1::Label>?

Labels can be used to organize documents in a way that can make it easy to find using the document search in SignWell. A document can have multiple labels.

Returns:



125
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 125

optional :labels, -> { SignwellSDK::Internal::Type::ArrayOf[SignwellSDK::V1::Label] }

#languageString?

Sets the language for the template and documents created from the template for all recipient side interactions including the document email and the document itself. Accepted languages: English, Français, Español, Deutsch, Polski, Português, Dansk, Nederlands, Italiano, Русский, Svenska, العربية, Ελληνικά, Türkçe, Slovenčina. Language should be sent in ISO 639-1 format: en, fr, es, de, pl, pt, da, nl, it, ru, sv, ar, el, tr, sk.

Returns:

  • (String, nil)


136
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 136

optional :language, String

#messageString?

Email message for the signature request that recipients will see. Defaults to the default system message or a template message (if the document is created from a template).

Returns:

  • (String, nil)


144
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 144

optional :message, String

#metadataHash{Symbol=>String}?

Optional key-value data that can be associated with the document. If set, will be available every time the document data is returned.

Returns:

  • (Hash{Symbol=>String}, nil)


151
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 151

optional :metadata, SignwellSDK::Internal::Type::HashOf[String]

#nameString?

The name of the template.

Returns:

  • (String, nil)


157
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 157

optional :name, String

#placeholdersArray<SignwellSDK::Models::V1::DocumentTemplateCreateParams::Placeholder>

Placeholders are generally job roles that must complete and/or sign the document. For example, a placeholder might be “Client” or “Legal Department”. When a document is created from the template, you assign a person to each placeholder.



27
28
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 27

required :placeholders,
-> { SignwellSDK::Internal::Type::ArrayOf[SignwellSDK::V1::DocumentTemplateCreateParams::Placeholder] }

#redirect_urlString?

A URL that recipients are redirected to after successfully signing a document.

Returns:

  • (String, nil)


163
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 163

optional :redirect_url, String

#remindersBoolean?

Whether to send signing reminders to recipients. Reminders are sent on day 3, day 6, and day 10 if set to ‘true`. Defaults to `true`.

Returns:

  • (Boolean, nil)


170
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 170

optional :reminders, SignwellSDK::Internal::Type::Boolean

#subjectString?

Email subject for the signature request that recipients will see. Defaults to the default system subject or a template subject (if the document is created from a template).

Returns:

  • (String, nil)


178
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 178

optional :subject, String

#text_tagsBoolean?

An alternative way (if you can’t use the recommended way) of placing fields in specific locations of your document by using special text tags. Useful when changing the content of your files changes the location of fields. See API documentation for “Text Tags” for details. Defaults to false.

Returns:

  • (Boolean, nil)


187
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 187

optional :text_tags, SignwellSDK::Internal::Type::Boolean