Class: SignwellSDK::Models::V1::DocumentTemplateCreateParams::AttachmentRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/signwell_sdk/models/v1/document_template_create_params.rb

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from SignwellSDK::Internal::Type::BaseModel

Instance Attribute Details

#nameString

Name of the requested attachment.

Returns:

  • (String)


289
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 289

required :name, String

#placeholder_idString

Unique identifier of the recipient that will view the attachment request.

Returns:

  • (String)


295
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 295

required :placeholder_id, String

#requiredBoolean?

Whether the recipient will need to upload the attachment to successfully complete/sign the document. Defaults to ‘true`.

Returns:

  • (Boolean, nil)


302
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 302

optional :required, SignwellSDK::Internal::Type::Boolean