Class: SignwellSDK::Models::V1::DocumentTemplateCreateParams::CopiedPlaceholder

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/signwell_sdk/models/v1/document_template_create_params.rb

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from SignwellSDK::Internal::Type::BaseModel

Instance Attribute Details

#nameString

Name of the placeholder.

Returns:

  • (String)


321
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 321

required :name, String

#preassigned_recipient_emailString?

In some cases, it may be necessary to pre-fill the name and email for a placeholder because it will always be the same person for all documents created from this template. This sets the email.

Returns:

  • (String, nil)


329
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 329

optional :preassigned_recipient_email, String

#preassigned_recipient_nameString?

In some cases, it may be necessary to pre-fill the name and email for a placeholder because it will always be the same person for all documents created from this template. This sets the name.

Returns:

  • (String, nil)


337
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 337

optional :preassigned_recipient_name, String