Class: SignwellSDK::Models::V1::DocumentTemplateCreateParams::Placeholder

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/signwell_sdk/models/v1/document_template_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(files:, placeholders:, allow_decline: nil, allow_reassign: nil, api_application_id: nil, apply_signing_order: nil, attachment_requests: nil, checkbox_groups: nil, copied_placeholders: nil, decline_redirect_url: nil, draft: nil, expires_in: nil, fields: nil, labels: nil, language: nil, message: nil, metadata: nil, name: nil, redirect_url: nil, reminders: nil, subject: nil, text_tags: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see SignwellSDK::Models::V1::DocumentTemplateCreateParams for more details.

Parameters:

  • files (Array<SignwellSDK::Models::V1::DocumentFile>)

    Document files can be uploaded by specifying a file URL or base64 string. Either

  • placeholders (Array<SignwellSDK::Models::V1::DocumentTemplateCreateParams::Placeholder>)

    Placeholders are generally job roles that must complete and/or sign the document

  • allow_decline (Boolean) (defaults to: nil)

    Whether to allow recipients the option to decline signing a document. If multipl

  • allow_reassign (Boolean) (defaults to: nil)

    In some cases a signer is not the right person to sign and may need to reassign

  • api_application_id (String) (defaults to: nil)

    Unique identifier for API Application settings to use. API Applications are opti

  • apply_signing_order (Boolean) (defaults to: nil)

    When set to ‘true` recipients will sign one at a time in the order of the `recip

  • attachment_requests (Array<SignwellSDK::Models::V1::DocumentTemplateCreateParams::AttachmentRequest>) (defaults to: nil)

    Attachments that a recipient must upload to complete the signing process. Attach

  • checkbox_groups (Array<SignwellSDK::Models::V1::TemplateCheckboxGroup>) (defaults to: nil)

    Checkbox fields that are placed on a document can be grouped with selection requ

  • copied_placeholders (Array<SignwellSDK::Models::V1::DocumentTemplateCreateParams::CopiedPlaceholder>) (defaults to: nil)

    Copied placeholders are emailed the final document once it has been completed by

  • decline_redirect_url (String) (defaults to: nil)

    A URL that recipients are redirected to if the document is declined.

  • draft (Boolean) (defaults to: nil)

    Whether the template can still be updated before it is ready for usage. If set t

  • expires_in (Integer) (defaults to: nil)

    Number of days before the signature request expires. Defaults to the account exp

  • fields (Array<Array<SignwellSDK::Models::V1::DocumentTemplateCreateParams::Field>>) (defaults to: nil)

    Document fields placed on a document for collecting data or signatures from reci

  • labels (Array<SignwellSDK::Models::V1::Label>) (defaults to: nil)

    Labels can be used to organize documents in a way that can make it easy to find

  • language (String) (defaults to: nil)

    Sets the language for the template and documents created from the template for a

  • message (String) (defaults to: nil)

    Email message for the signature request that recipients will see. Defaults to th

  • metadata (Hash{Symbol=>String}) (defaults to: nil)

    Optional key-value data that can be associated with the document. If set, will b

  • name (String) (defaults to: nil)

    The name of the template.

  • redirect_url (String) (defaults to: nil)

    A URL that recipients are redirected to after successfully signing a document.

  • reminders (Boolean) (defaults to: nil)

    Whether to send signing reminders to recipients. Reminders are sent on day 3, da

  • subject (String) (defaults to: nil)

    Email subject for the signature request that recipients will see. Defaults to th

  • text_tags (Boolean) (defaults to: nil)

    An alternative way (if you can’t use the recommended way) of placing fields in s

  • request_options (SignwellSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 239

class Placeholder < SignwellSDK::Internal::Type::BaseModel
  # @!attribute id
  #   A unique identifier that you will give to each placeholder. We recommend
  #   numbering sequentially from 1 to X. IDs are required for associating recipients
  #   to fields and more.
  #
  #   @return [String]
  required :id, String

  # @!attribute name
  #   Name of the placeholder.
  #
  #   @return [String]
  required :name, String

  # @!attribute preassigned_recipient_email
  #   In some cases, it may be necessary to pre-fill the name and email for a
  #   placeholder because it will always be the same person for all documents created
  #   from this template. This sets the email.
  #
  #   @return [String, nil]
  optional :preassigned_recipient_email, String

  # @!attribute preassigned_recipient_name
  #   In some cases, it may be necessary to pre-fill the name and email for a
  #   placeholder because it will always be the same person for all documents created
  #   from this template. This sets the name.
  #
  #   @return [String, nil]
  optional :preassigned_recipient_name, String

  # @!method initialize(id:, name:, preassigned_recipient_email: nil, preassigned_recipient_name: nil)
  #   Some parameter documentations has been truncated, see
  #   {SignwellSDK::Models::V1::DocumentTemplateCreateParams::Placeholder} for more
  #   details.
  #
  #   @param id [String] A unique identifier that you will give to each placeholder. We recommend numberi
  #
  #   @param name [String] Name of the placeholder.
  #
  #   @param preassigned_recipient_email [String] In some cases, it may be necessary to pre-fill the name and email for a placehol
  #
  #   @param preassigned_recipient_name [String] In some cases, it may be necessary to pre-fill the name and email for a placehol
end

Instance Attribute Details

#idString

A unique identifier that you will give to each placeholder. We recommend numbering sequentially from 1 to X. IDs are required for associating recipients to fields and more.

Returns:

  • (String)


246
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 246

required :id, String

#nameString

Name of the placeholder.

Returns:

  • (String)


252
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 252

required :name, String

#preassigned_recipient_emailString?

In some cases, it may be necessary to pre-fill the name and email for a placeholder because it will always be the same person for all documents created from this template. This sets the email.

Returns:

  • (String, nil)


260
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 260

optional :preassigned_recipient_email, String

#preassigned_recipient_nameString?

In some cases, it may be necessary to pre-fill the name and email for a placeholder because it will always be the same person for all documents created from this template. This sets the name.

Returns:

  • (String, nil)


268
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 268

optional :preassigned_recipient_name, String