Class: SignwellSDK::Models::V1::DocumentTemplateUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/signwell_sdk/models/v1/document_template_update_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(allow_decline: nil, allow_reassign: nil, api_application_id: nil, apply_signing_order: nil, checkbox_groups: nil, decline_redirect_url: nil, draft: nil, expires_in: nil, labels: nil, message: nil, metadata: nil, name: nil, redirect_url: nil, reminders: nil, subject: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see SignwellSDK::Models::V1::DocumentTemplateUpdateParams for more details.

Parameters:

  • allow_decline (Boolean) (defaults to: nil)

    Whether to allow recipients the option to decline signing a document. If multipl

  • allow_reassign (Boolean) (defaults to: nil)

    In some cases a signer is not the right person to sign and may need to reassign

  • api_application_id (String) (defaults to: nil)

    Unique identifier for API Application settings to use. API Applications are opti

  • apply_signing_order (Boolean) (defaults to: nil)

    When set to ‘true` recipients will sign one at a time in the order of the `recip

  • checkbox_groups (Array<SignwellSDK::Models::V1::TemplateCheckboxGroup>) (defaults to: nil)

    Checkbox fields that are placed on a document can be grouped with selection requ

  • decline_redirect_url (String) (defaults to: nil)

    A URL that recipients are redirected to if the document is declined.

  • draft (Boolean) (defaults to: nil)

    Whether the template can still be updated before it is ready for usage. If set t

  • expires_in (Integer) (defaults to: nil)

    Number of days before the signature request expires. Defaults to the account exp

  • labels (Array<SignwellSDK::Models::V1::Label>) (defaults to: nil)

    Labels can be used to organize documents in a way that can make it easy to find

  • message (String) (defaults to: nil)

    Email message for the signature request that recipients will see. Defaults to th

  • metadata (Hash{Symbol=>String}) (defaults to: nil)

    Optional key-value data that can be associated with the document. If set, will b

  • name (String) (defaults to: nil)

    The name of the template.

  • redirect_url (String) (defaults to: nil)

    A URL that recipients are redirected to after successfully signing a document.

  • reminders (Boolean) (defaults to: nil)

    Whether to send signing reminders to recipients. Reminders are sent on day 3, da

  • subject (String) (defaults to: nil)

    Email subject for the signature request that recipients will see. Defaults to th

  • request_options (SignwellSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/signwell_sdk/models/v1/document_template_update_params.rb', line 124

Instance Attribute Details

#allow_declineBoolean?

Whether to allow recipients the option to decline signing a document. If multiple signers are involved in a document, any single recipient can cancel the entire document signing process by declining to sign.

Returns:

  • (Boolean, nil)


17
# File 'lib/signwell_sdk/models/v1/document_template_update_params.rb', line 17

optional :allow_decline, SignwellSDK::Internal::Type::Boolean

#allow_reassignBoolean?

In some cases a signer is not the right person to sign and may need to reassign their signing responsibilities to another person. This feature allows them to reassign the document to someone else.

Returns:

  • (Boolean, nil)


25
# File 'lib/signwell_sdk/models/v1/document_template_update_params.rb', line 25

optional :allow_reassign, SignwellSDK::Internal::Type::Boolean

#api_application_idString?

Unique identifier for API Application settings to use. API Applications are optional and mainly used when isolating OAuth apps or for more control over embedded API settings

Returns:

  • (String, nil)


33
# File 'lib/signwell_sdk/models/v1/document_template_update_params.rb', line 33

optional :api_application_id, String

#apply_signing_orderBoolean?

When set to ‘true` recipients will sign one at a time in the order of the `recipients` collection of this request.

Returns:

  • (Boolean, nil)


40
# File 'lib/signwell_sdk/models/v1/document_template_update_params.rb', line 40

optional :apply_signing_order, SignwellSDK::Internal::Type::Boolean

#checkbox_groupsArray<SignwellSDK::Models::V1::TemplateCheckboxGroup>?

Checkbox fields that are placed on a document can be grouped with selection requirements. At least 2 checkbox fields in an array of fields must be assigned to the same recipient.



48
49
# File 'lib/signwell_sdk/models/v1/document_template_update_params.rb', line 48

optional :checkbox_groups,
-> { SignwellSDK::Internal::Type::ArrayOf[SignwellSDK::V1::TemplateCheckboxGroup] }

#decline_redirect_urlString?

A URL that recipients are redirected to if the document is declined.

Returns:

  • (String, nil)


55
# File 'lib/signwell_sdk/models/v1/document_template_update_params.rb', line 55

optional :decline_redirect_url, String

#draftBoolean?

Whether the template can still be updated before it is ready for usage. If set to ‘false` the template is marked as `Available` and it will be ready for use. Defaults to `false`.

Returns:

  • (Boolean, nil)


63
# File 'lib/signwell_sdk/models/v1/document_template_update_params.rb', line 63

optional :draft, SignwellSDK::Internal::Type::Boolean

#expires_inInteger?

Number of days before the signature request expires. Defaults to the account expiration setting or template expiration (if the document is created from a template).

Returns:

  • (Integer, nil)


71
# File 'lib/signwell_sdk/models/v1/document_template_update_params.rb', line 71

optional :expires_in, Integer

#labelsArray<SignwellSDK::Models::V1::Label>?

Labels can be used to organize documents in a way that can make it easy to find using the document search in SignWell. A document can have multiple labels. Updating labels on a document will replace any existing labels for that document.

Returns:



80
# File 'lib/signwell_sdk/models/v1/document_template_update_params.rb', line 80

optional :labels, -> { SignwellSDK::Internal::Type::ArrayOf[SignwellSDK::V1::Label] }

#messageString?

Email message for the signature request that recipients will see. Defaults to the default system message or a template message (if the document is created from a template).

Returns:

  • (String, nil)


88
# File 'lib/signwell_sdk/models/v1/document_template_update_params.rb', line 88

optional :message, String

#metadataHash{Symbol=>String}?

Optional key-value data that can be associated with the document. If set, will be available every time the document data is returned.

Returns:

  • (Hash{Symbol=>String}, nil)


95
# File 'lib/signwell_sdk/models/v1/document_template_update_params.rb', line 95

optional :metadata, SignwellSDK::Internal::Type::HashOf[String]

#nameString?

The name of the template.

Returns:

  • (String, nil)


101
# File 'lib/signwell_sdk/models/v1/document_template_update_params.rb', line 101

optional :name, String

#redirect_urlString?

A URL that recipients are redirected to after successfully signing a document.

Returns:

  • (String, nil)


107
# File 'lib/signwell_sdk/models/v1/document_template_update_params.rb', line 107

optional :redirect_url, String

#remindersBoolean?

Whether to send signing reminders to recipients. Reminders are sent on day 3, day 6, and day 10 if set to ‘true`. Defaults to `true`.

Returns:

  • (Boolean, nil)


114
# File 'lib/signwell_sdk/models/v1/document_template_update_params.rb', line 114

optional :reminders, SignwellSDK::Internal::Type::Boolean

#subjectString?

Email subject for the signature request that recipients will see. Defaults to the default system subject or a template subject (if the document is created from a template).

Returns:

  • (String, nil)


122
# File 'lib/signwell_sdk/models/v1/document_template_update_params.rb', line 122

optional :subject, String