Class: SignwellSDK::Models::V1::TemplateCheckboxGroup
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SignwellSDK::Models::V1::TemplateCheckboxGroup
- Defined in:
- lib/signwell_sdk/models/v1/template_checkbox_group.rb
Instance Attribute Summary collapse
- #checkbox_ids ⇒ Array<String>
-
#exact_value ⇒ Integer?
The exact number of checkboxes that must be checked in the group.
-
#group_name ⇒ String
A unique identifier for the checkbox group.
-
#max_value ⇒ Integer?
The maximum number of checkboxes that can be checked in the group.
-
#min_value ⇒ Integer?
The minimum number of checkboxes that must be checked in the group.
-
#placeholder_id ⇒ String
The recipient ID associated with the checkbox group.
-
#required ⇒ Boolean?
Whether the group must be completed by the recipient.
-
#validation ⇒ Symbol, ...
Set requirements for the group of one or multiple selections by the recipient.
Instance Method Summary collapse
-
#initialize(checkbox_ids:, group_name:, placeholder_id:, exact_value: nil, max_value: nil, min_value: nil, required: nil, validation: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see TemplateCheckboxGroup for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(checkbox_ids:, group_name:, placeholder_id:, exact_value: nil, max_value: nil, min_value: nil, required: nil, validation: nil) ⇒ Object
Some parameter documentations has been truncated, see SignwellSDK::Models::V1::TemplateCheckboxGroup for more details.
|
|
# File 'lib/signwell_sdk/models/v1/template_checkbox_group.rb', line 58
|
Instance Attribute Details
#checkbox_ids ⇒ Array<String>
10 |
# File 'lib/signwell_sdk/models/v1/template_checkbox_group.rb', line 10 required :checkbox_ids, SignwellSDK::Internal::Type::ArrayOf[String] |
#exact_value ⇒ Integer?
The exact number of checkboxes that must be checked in the group. (Only for validation: exact)
29 |
# File 'lib/signwell_sdk/models/v1/template_checkbox_group.rb', line 29 optional :exact_value, Integer |
#group_name ⇒ String
A unique identifier for the checkbox group.
16 |
# File 'lib/signwell_sdk/models/v1/template_checkbox_group.rb', line 16 required :group_name, String |
#max_value ⇒ Integer?
The maximum number of checkboxes that can be checked in the group. (Only for validation: maximum and range)
36 |
# File 'lib/signwell_sdk/models/v1/template_checkbox_group.rb', line 36 optional :max_value, Integer |
#min_value ⇒ Integer?
The minimum number of checkboxes that must be checked in the group. (Only for validation: minimum and range)
43 |
# File 'lib/signwell_sdk/models/v1/template_checkbox_group.rb', line 43 optional :min_value, Integer |
#placeholder_id ⇒ String
The recipient ID associated with the checkbox group.
22 |
# File 'lib/signwell_sdk/models/v1/template_checkbox_group.rb', line 22 required :placeholder_id, String |
#required ⇒ Boolean?
Whether the group must be completed by the recipient. Defaults to false.
49 |
# File 'lib/signwell_sdk/models/v1/template_checkbox_group.rb', line 49 optional :required, SignwellSDK::Internal::Type::Boolean |
#validation ⇒ Symbol, ...
Set requirements for the group of one or multiple selections by the recipient. Defaults to minimum. Validation values: minimum, maximum, exact, range.
56 |
# File 'lib/signwell_sdk/models/v1/template_checkbox_group.rb', line 56 optional :validation, enum: -> { SignwellSDK::CheckboxValidation } |