Class: SignwellSDK::Models::V1::AttachmentRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SignwellSDK::Models::V1::AttachmentRequest
- Defined in:
- lib/signwell_sdk/models/v1/attachment_request.rb
Instance Attribute Summary collapse
-
#name ⇒ String
Name of the requested attachment.
-
#recipient_id ⇒ String
Unique identifier of the recipient that will view the attachment request.
-
#required ⇒ Boolean?
Whether the recipient will need to upload the attachment to successfully complete/sign the document.
Instance Method Summary collapse
-
#initialize(name:, recipient_id:, required: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see AttachmentRequest for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:, recipient_id:, required: nil) ⇒ Object
Some parameter documentations has been truncated, see SignwellSDK::Models::V1::AttachmentRequest for more details.
|
|
# File 'lib/signwell_sdk/models/v1/attachment_request.rb', line 26
|
Instance Attribute Details
#name ⇒ String
Name of the requested attachment.
11 |
# File 'lib/signwell_sdk/models/v1/attachment_request.rb', line 11 required :name, String |
#recipient_id ⇒ String
Unique identifier of the recipient that will view the attachment request.
17 |
# File 'lib/signwell_sdk/models/v1/attachment_request.rb', line 17 required :recipient_id, String |
#required ⇒ Boolean?
Whether the recipient will need to upload the attachment to successfully complete/sign the document. Defaults to ‘true`.
24 |
# File 'lib/signwell_sdk/models/v1/attachment_request.rb', line 24 optional :required, SignwellSDK::Internal::Type::Boolean |