Class: SignwellSDK::Models::V1::BulkSendCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SignwellSDK::Models::V1::BulkSendCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/signwell_sdk/models/v1/bulk_send_create_params.rb
Overview
Instance Attribute Summary collapse
-
#api_application_id ⇒ String?
Unique identifier for API Application settings to use.
-
#apply_signing_order ⇒ Boolean?
When set to ‘true` recipients will sign one at a time in the order of the `recipients` collection of this request.
-
#bulk_send_csv ⇒ String
A RFC 4648 base64 string of the template CSV file to be validated.
-
#custom_requester_email ⇒ String?
Sets the custom requester email for the document.
-
#custom_requester_name ⇒ String?
Sets the custom requester name for the document.
-
#message ⇒ String?
Email message for the signature request that recipients will see.
-
#name ⇒ String?
The name of the Bulk Send.
-
#skip_row_errors ⇒ Boolean?
Whether to skip errors in the rows.
-
#subject ⇒ String?
Email subject for the signature request that recipients will see.
-
#template_ids ⇒ Array<String>
Unique identifiers for a list of templates.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(bulk_send_csv:, template_ids:, api_application_id: nil, apply_signing_order: nil, custom_requester_email: nil, custom_requester_name: nil, message: nil, name: nil, skip_row_errors: nil, subject: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see BulkSendCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(bulk_send_csv:, template_ids:, api_application_id: nil, apply_signing_order: nil, custom_requester_email: nil, custom_requester_name: nil, message: nil, name: nil, skip_row_errors: nil, subject: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see SignwellSDK::Models::V1::BulkSendCreateParams for more details.
|
|
# File 'lib/signwell_sdk/models/v1/bulk_send_create_params.rb', line 79
|
Instance Attribute Details
#api_application_id ⇒ String?
Unique identifier for API Application settings to use. API Applications are optional and mainly used when isolating OAuth apps or for more control over embedded API settings
29 |
# File 'lib/signwell_sdk/models/v1/bulk_send_create_params.rb', line 29 optional :api_application_id, String |
#apply_signing_order ⇒ Boolean?
When set to ‘true` recipients will sign one at a time in the order of the `recipients` collection of this request.
36 |
# File 'lib/signwell_sdk/models/v1/bulk_send_create_params.rb', line 36 optional :apply_signing_order, SignwellSDK::Internal::Type::Boolean |
#bulk_send_csv ⇒ String
A RFC 4648 base64 string of the template CSV file to be validated.
15 |
# File 'lib/signwell_sdk/models/v1/bulk_send_create_params.rb', line 15 required :bulk_send_csv, String |
#custom_requester_email ⇒ String?
Sets the custom requester email for the document. When set, this is the email used for all email communications, signing notifications, and in the audit file.
43 |
# File 'lib/signwell_sdk/models/v1/bulk_send_create_params.rb', line 43 optional :custom_requester_email, String |
#custom_requester_name ⇒ String?
Sets the custom requester name for the document. When set, this is the name used for all email communications, signing notifications, and in the audit file.
50 |
# File 'lib/signwell_sdk/models/v1/bulk_send_create_params.rb', line 50 optional :custom_requester_name, String |
#message ⇒ String?
Email message for the signature request that recipients will see. Defaults to the default system message or a template message.
57 |
# File 'lib/signwell_sdk/models/v1/bulk_send_create_params.rb', line 57 optional :message, String |
#name ⇒ String?
The name of the Bulk Send. Will be used as the document name for each of the documents.
64 |
# File 'lib/signwell_sdk/models/v1/bulk_send_create_params.rb', line 64 optional :name, String |
#skip_row_errors ⇒ Boolean?
Whether to skip errors in the rows. Defaults to ‘false`.
70 |
# File 'lib/signwell_sdk/models/v1/bulk_send_create_params.rb', line 70 optional :skip_row_errors, SignwellSDK::Internal::Type::Boolean |
#subject ⇒ String?
Email subject for the signature request that recipients will see. Defaults to the default system subject or a template subject.
77 |
# File 'lib/signwell_sdk/models/v1/bulk_send_create_params.rb', line 77 optional :subject, String |
#template_ids ⇒ Array<String>
Unique identifiers for a list of templates.
21 |
# File 'lib/signwell_sdk/models/v1/bulk_send_create_params.rb', line 21 required :template_ids, SignwellSDK::Internal::Type::ArrayOf[String] |