Class: SignwellSDK::Models::V1::BulkSendValidateCsvParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SignwellSDK::Models::V1::BulkSendValidateCsvParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/signwell_sdk/models/v1/bulk_send_validate_csv_params.rb
Overview
Instance Attribute Summary collapse
-
#bulk_send_csv ⇒ String
A RFC 4648 base64 string of the template CSV file to be validated.
-
#template_ids ⇒ Array<String>
Specify one or more templates to generate a single blank CSV file that will contain available columns for your recipient data.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(bulk_send_csv:, template_ids:, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see BulkSendValidateCsvParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(bulk_send_csv:, template_ids:, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see SignwellSDK::Models::V1::BulkSendValidateCsvParams for more details.
|
|
# File 'lib/signwell_sdk/models/v1/bulk_send_validate_csv_params.rb', line 27
|
Instance Attribute Details
#bulk_send_csv ⇒ String
A RFC 4648 base64 string of the template CSV file to be validated.
15 |
# File 'lib/signwell_sdk/models/v1/bulk_send_validate_csv_params.rb', line 15 required :bulk_send_csv, String |
#template_ids ⇒ Array<String>
Specify one or more templates to generate a single blank CSV file that will contain available columns for your recipient data. The template_ids[] parameter is an array of template IDs (e.g.,‘/?template_ids[]=5a67dbd7-928a-4ea0-a7e2-e476a0eb045f&template_ids=d7315111-c671-4b15-8354-c9a19bbaefa0`). Each ID should be a separate parameter in the query string.
25 |
# File 'lib/signwell_sdk/models/v1/bulk_send_validate_csv_params.rb', line 25 required :template_ids, SignwellSDK::Internal::Type::ArrayOf[String] |