Class: SignwellSDK::Models::V1::DocumentCreateFromTemplateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SignwellSDK::Models::V1::DocumentCreateFromTemplateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/signwell_sdk/models/v1/document_create_from_template_params.rb
Overview
Defined Under Namespace
Classes: Field, File, Recipient, TemplateField
Instance Attribute Summary collapse
-
#allow_decline ⇒ Boolean?
Whether to allow recipients the option to decline signing a document.
-
#allow_reassign ⇒ Boolean?
In some cases a signer is not the right person to sign and may need to reassign their signing responsibilities to another person.
-
#api_application_id ⇒ String?
Unique identifier for API Application settings to use.
-
#apply_signing_order ⇒ Boolean?
When set to ‘true` recipients will sign one at a time in the order of the `recipients` collection of this request.
-
#attachment_requests ⇒ Array<SignwellSDK::Models::V1::AttachmentRequest>?
Attachments that a recipient must upload to complete the signing process.
-
#checkbox_groups ⇒ Array<SignwellSDK::Models::V1::CheckboxGroup>?
Checkbox fields that are placed on a document can be grouped with selection requirements.
-
#copied_contacts ⇒ Array<SignwellSDK::Models::V1::CopiedContact>?
Copied contacts are emailed the final document once it has been completed by all recipients.
-
#custom_requester_email ⇒ String?
Sets the custom requester email for the document.
-
#custom_requester_name ⇒ String?
Sets the custom requester name for the document.
-
#decline_redirect_url ⇒ String?
A URL that recipients are redirected to if the document is declined.
-
#draft ⇒ Boolean?
Whether the document can still be updated before sending a signature request.
-
#embedded_signing ⇒ Boolean?
When set to ‘true` it enables embedded signing in your website/web application.
-
#embedded_signing_notifications ⇒ Boolean?
On embedding signing, document owners (and CC’d contacts) do not get a notification email when documents have been completed.
-
#expires_in ⇒ Integer?
Number of days before the signature request expires.
-
#fields ⇒ Array<Array<SignwellSDK::Models::V1::DocumentCreateFromTemplateParams::Field>>?
Fields to be added to any appended files (not existing files).
- #files ⇒ Array<SignwellSDK::Models::V1::DocumentCreateFromTemplateParams::File>?
-
#labels ⇒ Array<SignwellSDK::Models::V1::Label>?
Labels can be used to organize documents in a way that can make it easy to find using the document search in SignWell.
-
#language ⇒ String?
Sets the language for all recipients on the document and updates all recipient side interactions including the document email and the document itself.
-
#message ⇒ String?
Email message for the signature request that recipients will see.
-
#metadata ⇒ Hash{Symbol=>String}?
Optional key-value data that can be associated with the document.
-
#name ⇒ String?
The name of the document.
-
#recipients ⇒ Array<SignwellSDK::Models::V1::DocumentCreateFromTemplateParams::Recipient>
Document recipients are people that must complete and/or sign a document.
-
#redirect_url ⇒ String?
A URL that recipients are redirected to after successfully signing a document.
-
#reminders ⇒ Boolean?
Whether to send signing reminders to recipients.
-
#subject ⇒ String?
Email subject for the signature request that recipients will see.
-
#template_fields ⇒ Array<SignwellSDK::Models::V1::DocumentCreateFromTemplateParams::TemplateField>?
Fields of your template(s) that you can prepopulate with values.
-
#template_id ⇒ String?
Use when you have to create a document from a single template.
-
#template_ids ⇒ Array<String>?
Use when you have to create a document from multiple templates.
-
#test_mode ⇒ Boolean?
Set to ‘true` to enable Test Mode.
-
#text_tags ⇒ Boolean?
An alternative way (if you can’t use the recommended way) of placing fields in specific locations of your document by using special text tags.
-
#with_signature_page ⇒ Boolean?
When set to ‘true` the document will have a signature page added to the end, and all signers will be required to add their signature on that page.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(name:, file_base64: nil, file_url: nil) ⇒ Object
constructor
Additional files to be appended to the document.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:, file_base64: nil, file_url: nil) ⇒ Object
Additional files to be appended to the document. Will not replace existing files from the template. Document files can be uploaded by specifying a file URL or base64 string. Either ‘file_url` or `file_base64` must be present (not both). Valid file types are: .pdf, .docx, .jpg, .png, .ppt, .xls, .pages, and .txt.
|
|
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 385
|
Instance Attribute Details
#allow_decline ⇒ Boolean?
Whether to allow recipients the option to decline signing a document. If multiple signers are involved in a document, any single recipient can cancel the entire document signing process by declining to sign.
26 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 26 optional :allow_decline, SignwellSDK::Internal::Type::Boolean |
#allow_reassign ⇒ Boolean?
In some cases a signer is not the right person to sign and may need to reassign their signing responsibilities to another person. This feature allows them to reassign the document to someone else.
34 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 34 optional :allow_reassign, SignwellSDK::Internal::Type::Boolean |
#api_application_id ⇒ String?
Unique identifier for API Application settings to use. API Applications are optional and mainly used when isolating OAuth apps or for more control over embedded API settings
42 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 42 optional :api_application_id, String |
#apply_signing_order ⇒ Boolean?
When set to ‘true` recipients will sign one at a time in the order of the `recipients` collection of this request.
49 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 49 optional :apply_signing_order, SignwellSDK::Internal::Type::Boolean |
#attachment_requests ⇒ Array<SignwellSDK::Models::V1::AttachmentRequest>?
Attachments that a recipient must upload to complete the signing process. Attachment requests are shown after all document fields have been completed.
56 57 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 56 optional :attachment_requests, -> { SignwellSDK::Internal::Type::ArrayOf[SignwellSDK::V1::AttachmentRequest] } |
#checkbox_groups ⇒ Array<SignwellSDK::Models::V1::CheckboxGroup>?
Checkbox fields that are placed on a document can be grouped with selection requirements. At least 2 checkbox fields in an array of fields must be assigned to the same recipient.
65 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 65 optional :checkbox_groups, -> { SignwellSDK::Internal::Type::ArrayOf[SignwellSDK::V1::CheckboxGroup] } |
#copied_contacts ⇒ Array<SignwellSDK::Models::V1::CopiedContact>?
Copied contacts are emailed the final document once it has been completed by all recipients.
72 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 72 optional :copied_contacts, -> { SignwellSDK::Internal::Type::ArrayOf[SignwellSDK::V1::CopiedContact] } |
#custom_requester_email ⇒ String?
Sets the custom requester email for the document. When set, this is the email used for all email communications, signing notifications, and in the audit file.
79 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 79 optional :custom_requester_email, String |
#custom_requester_name ⇒ String?
Sets the custom requester name for the document. When set, this is the name used for all email communications, signing notifications, and in the audit file.
86 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 86 optional :custom_requester_name, String |
#decline_redirect_url ⇒ String?
A URL that recipients are redirected to if the document is declined.
92 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 92 optional :decline_redirect_url, String |
#draft ⇒ Boolean?
Whether the document can still be updated before sending a signature request. If set to ‘false` the document is sent for signing as part of this request. Defaults to `false`.
100 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 100 optional :draft, SignwellSDK::Internal::Type::Boolean |
#embedded_signing ⇒ Boolean?
When set to ‘true` it enables embedded signing in your website/web application. Embedded functionality works with an iFrame and email authentication is disabled. :embedded_signinig defaults to `false`.
108 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 108 optional :embedded_signing, SignwellSDK::Internal::Type::Boolean |
#embedded_signing_notifications ⇒ Boolean?
On embedding signing, document owners (and CC’d contacts) do not get a notification email when documents have been completed. Setting this param to ‘true` will send out those final completed notifications. Default is `false`
116 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 116 optional :embedded_signing_notifications, SignwellSDK::Internal::Type::Boolean |
#expires_in ⇒ Integer?
Number of days before the signature request expires. Defaults to the account expiration setting or template expiration (if the document is created from a template).
124 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 124 optional :expires_in, Integer |
#fields ⇒ Array<Array<SignwellSDK::Models::V1::DocumentCreateFromTemplateParams::Field>>?
Fields to be added to any appended files (not existing files). Document fields placed on a document for collecting data or signatures from recipients. Field data should be sent as a 2-dimensional JSON array. One array of fields is needed for each file in the files array. An array of fields can be empty if you have a file that does not contain any fields.
134 135 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 134 optional :fields, -> { SignwellSDK::Internal::Type::ArrayOf[SignwellSDK::Internal::Type::ArrayOf[SignwellSDK::V1::DocumentCreateFromTemplateParams::Field]] } |
#files ⇒ Array<SignwellSDK::Models::V1::DocumentCreateFromTemplateParams::File>?
140 141 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 140 optional :files, -> { SignwellSDK::Internal::Type::ArrayOf[SignwellSDK::V1::DocumentCreateFromTemplateParams::File] } |
#labels ⇒ Array<SignwellSDK::Models::V1::Label>?
Labels can be used to organize documents in a way that can make it easy to find using the document search in SignWell. A document can have multiple labels. Updating labels on a document will replace any existing labels for that document.
150 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 150 optional :labels, -> { SignwellSDK::Internal::Type::ArrayOf[SignwellSDK::V1::Label] } |
#language ⇒ String?
Sets the language for all recipients on the document and updates all recipient side interactions including the document email and the document itself. Accepted languages: English, Français, Español, Deutsch, Polski, Português, Dansk, Nederlands, Italiano, Русский, Svenska, العربية, Ελληνικά, Türkçe, Slovenčina. Defaults to English. Language should be sent in ISO 639-1 format: en, fr, es, de, pl, pt, da, nl, it, ru, sv, ar, el, tr, sk.
161 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 161 optional :language, String |
#message ⇒ String?
Email message for the signature request that recipients will see. Defaults to the default system message or a template message (if the document is created from a template).
169 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 169 optional :message, String |
#metadata ⇒ Hash{Symbol=>String}?
Optional key-value data that can be associated with the document. If set, will be available every time the document data is returned.
176 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 176 optional :metadata, SignwellSDK::Internal::Type::HashOf[String] |
#name ⇒ String?
The name of the document.
182 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 182 optional :name, String |
#recipients ⇒ Array<SignwellSDK::Models::V1::DocumentCreateFromTemplateParams::Recipient>
Document recipients are people that must complete and/or sign a document. Recipients of the document must be assigned to a placeholder of the template. Recipients will inherit all placeholder fields and settings.
17 18 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 17 required :recipients, -> { SignwellSDK::Internal::Type::ArrayOf[SignwellSDK::V1::DocumentCreateFromTemplateParams::Recipient] } |
#redirect_url ⇒ String?
A URL that recipients are redirected to after successfully signing a document.
188 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 188 optional :redirect_url, String |
#reminders ⇒ Boolean?
Whether to send signing reminders to recipients. Reminders are sent on day 3, day 6, and day 10 if set to ‘true`. Defaults to `true`.
195 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 195 optional :reminders, SignwellSDK::Internal::Type::Boolean |
#subject ⇒ String?
Email subject for the signature request that recipients will see. Defaults to the default system subject or a template subject (if the document is created from a template).
203 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 203 optional :subject, String |
#template_fields ⇒ Array<SignwellSDK::Models::V1::DocumentCreateFromTemplateParams::TemplateField>?
Fields of your template(s) that you can prepopulate with values. Signature and Initials fields cannot be signed through the API.
210 211 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 210 optional :template_fields, -> { SignwellSDK::Internal::Type::ArrayOf[SignwellSDK::V1::DocumentCreateFromTemplateParams::TemplateField] } |
#template_id ⇒ String?
Use when you have to create a document from a single template. Either :template_id or :template_ids must be present in the request, not both.
218 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 218 optional :template_id, String |
#template_ids ⇒ Array<String>?
Use when you have to create a document from multiple templates. Either :template_id or :template_ids must be present in the request, not both.
225 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 225 optional :template_ids, SignwellSDK::Internal::Type::ArrayOf[String] |
#test_mode ⇒ Boolean?
Set to ‘true` to enable Test Mode. Documents created with Test Mode do not count towards API billing and are not legally binding. Defaults to `false`
232 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 232 optional :test_mode, SignwellSDK::Internal::Type::Boolean |
#text_tags ⇒ Boolean?
An alternative way (if you can’t use the recommended way) of placing fields in specific locations of your document by using special text tags. Useful when changing the content of your files changes the location of fields. See API documentation for “Text Tags” for details. Defaults to false.
241 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 241 optional :text_tags, SignwellSDK::Internal::Type::Boolean |
#with_signature_page ⇒ Boolean?
When set to ‘true` the document will have a signature page added to the end, and all signers will be required to add their signature on that page.
248 |
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 248 optional :with_signature_page, SignwellSDK::Internal::Type::Boolean |
Class Method Details
.variants ⇒ Array(String, Boolean, Float)
|
|
# File 'lib/signwell_sdk/models/v1/document_create_from_template_params.rb', line 666
|