Class: SignwellSDK::Models::V1::DocumentCreateParams::Recipient
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SignwellSDK::Models::V1::DocumentCreateParams::Recipient
- Defined in:
- lib/signwell_sdk/models/v1/document_create_params.rb
Instance Attribute Summary collapse
-
#email ⇒ String
Email address for the recipient.
-
#id ⇒ String
A unique identifier that you will give to each recipient.
-
#message ⇒ String?
Email message for the signature request that the recipient will see.
-
#name ⇒ String?
Name of the recipient.
-
#passcode ⇒ String?
If set, signers assigned with a passcode will be required to enter the passcode before they’re able to view and complete the document.
-
#send_email ⇒ Boolean?
Applies on when ‘embedded_signing` is `true`.
-
#send_email_delay ⇒ Integer?
If ‘send_email` is `true` recipients will receive a new document notification immediately.
-
#subject ⇒ String?
Email subject for the signature request that the recipient will see.
Instance Method Summary collapse
-
#initialize(files:, recipients:, allow_decline: nil, allow_reassign: nil, api_application_id: nil, apply_signing_order: nil, attachment_requests: nil, checkbox_groups: nil, copied_contacts: nil, custom_requester_email: nil, custom_requester_name: nil, decline_redirect_url: nil, draft: nil, embedded_signing: nil, embedded_signing_notifications: nil, expires_in: nil, fields: nil, labels: nil, language: nil, message: nil, metadata: nil, name: nil, redirect_url: nil, reminders: nil, subject: nil, test_mode: nil, text_tags: nil, with_signature_page: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see SignwellSDK::Models::V1::DocumentCreateParams for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(files:, recipients:, allow_decline: nil, allow_reassign: nil, api_application_id: nil, apply_signing_order: nil, attachment_requests: nil, checkbox_groups: nil, copied_contacts: nil, custom_requester_email: nil, custom_requester_name: nil, decline_redirect_url: nil, draft: nil, embedded_signing: nil, embedded_signing_notifications: nil, expires_in: nil, fields: nil, labels: nil, language: nil, message: nil, metadata: nil, name: nil, redirect_url: nil, reminders: nil, subject: nil, test_mode: nil, text_tags: nil, with_signature_page: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see SignwellSDK::Models::V1::DocumentCreateParams for more details.
290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 |
# File 'lib/signwell_sdk/models/v1/document_create_params.rb', line 290 class Recipient < SignwellSDK::Internal::Type::BaseModel # @!attribute id # A unique identifier that you will give to each recipient. We recommend numbering # sequentially from 1 to X. IDs are required for associating recipients to fields # and more. # # @return [String] required :id, String # @!attribute email # Email address for the recipient. # # @return [String] required :email, String # @!attribute message # Email message for the signature request that the recipient will see. Overrides # the general message for the document. # # @return [String, nil] optional :message, String # @!attribute name # Name of the recipient. # # @return [String, nil] optional :name, String # @!attribute passcode # If set, signers assigned with a passcode will be required to enter the passcode # before they’re able to view and complete the document. # # @return [String, nil] optional :passcode, String # @!attribute send_email # Applies on when `embedded_signing` is `true`. By default, recipients are not # notified through email to sign when doing embedded signing. Setting this to # `true` will send a notification email to the recipient. Default is `false`. # # @return [Boolean, nil] optional :send_email, SignwellSDK::Internal::Type::Boolean # @!attribute send_email_delay # If `send_email` is `true` recipients will receive a new document notification # immediately. In the case of embedded signing, you can delay this notification to # only send if the document is not completed within a few minutes. The email # notification will not go out if the document is completed before the delay time # is over. Valid values are in minutes ranging from `0` to `60`. Defaults to `0`. # # @return [Integer, nil] optional :send_email_delay, Integer # @!attribute subject # Email subject for the signature request that the recipient will see. Overrides # the general subject for the document. # # @return [String, nil] optional :subject, String # @!method initialize(id:, email:, message: nil, name: nil, passcode: nil, send_email: nil, send_email_delay: nil, subject: nil) # Some parameter documentations has been truncated, see # {SignwellSDK::Models::V1::DocumentCreateParams::Recipient} for more details. # # @param id [String] A unique identifier that you will give to each recipient. We recommend numbering # # @param email [String] Email address for the recipient. # # @param message [String] Email message for the signature request that the recipient will see. Overrides t # # @param name [String] Name of the recipient. # # @param passcode [String] If set, signers assigned with a passcode will be required to enter the passcode # # @param send_email [Boolean] Applies on when `embedded_signing` is `true`. By default, recipients are not not # # @param send_email_delay [Integer] If `send_email` is `true` recipients will receive a new document notification im # # @param subject [String] Email subject for the signature request that the recipient will see. Overrides t end |
Instance Attribute Details
#email ⇒ String
Email address for the recipient.
303 |
# File 'lib/signwell_sdk/models/v1/document_create_params.rb', line 303 required :email, String |
#id ⇒ String
A unique identifier that you will give to each recipient. We recommend numbering sequentially from 1 to X. IDs are required for associating recipients to fields and more.
297 |
# File 'lib/signwell_sdk/models/v1/document_create_params.rb', line 297 required :id, String |
#message ⇒ String?
Email message for the signature request that the recipient will see. Overrides the general message for the document.
310 |
# File 'lib/signwell_sdk/models/v1/document_create_params.rb', line 310 optional :message, String |
#name ⇒ String?
Name of the recipient.
316 |
# File 'lib/signwell_sdk/models/v1/document_create_params.rb', line 316 optional :name, String |
#passcode ⇒ String?
If set, signers assigned with a passcode will be required to enter the passcode before they’re able to view and complete the document.
323 |
# File 'lib/signwell_sdk/models/v1/document_create_params.rb', line 323 optional :passcode, String |
#send_email ⇒ Boolean?
Applies on when ‘embedded_signing` is `true`. By default, recipients are not notified through email to sign when doing embedded signing. Setting this to `true` will send a notification email to the recipient. Default is `false`.
331 |
# File 'lib/signwell_sdk/models/v1/document_create_params.rb', line 331 optional :send_email, SignwellSDK::Internal::Type::Boolean |
#send_email_delay ⇒ Integer?
If ‘send_email` is `true` recipients will receive a new document notification immediately. In the case of embedded signing, you can delay this notification to only send if the document is not completed within a few minutes. The email notification will not go out if the document is completed before the delay time is over. Valid values are in minutes ranging from `0` to `60`. Defaults to `0`.
341 |
# File 'lib/signwell_sdk/models/v1/document_create_params.rb', line 341 optional :send_email_delay, Integer |
#subject ⇒ String?
Email subject for the signature request that the recipient will see. Overrides the general subject for the document.
348 |
# File 'lib/signwell_sdk/models/v1/document_create_params.rb', line 348 optional :subject, String |