Class: SignwellSDK::Models::V1::DocumentRemindParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SignwellSDK::Models::V1::DocumentRemindParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/signwell_sdk/models/v1/document_remind_params.rb
Overview
Defined Under Namespace
Classes: Recipient
Instance Attribute Summary collapse
-
#recipients ⇒ Array<SignwellSDK::Models::V1::DocumentRemindParams::Recipient>?
Optional list if recipients within the document to send a reminder email to.
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from SignwellSDK::Internal::Type::BaseModel
Instance Attribute Details
#recipients ⇒ Array<SignwellSDK::Models::V1::DocumentRemindParams::Recipient>?
Optional list if recipients within the document to send a reminder email to. If none are specified, all recipients that have not signed yet will receive a reminder email.
17 18 |
# File 'lib/signwell_sdk/models/v1/document_remind_params.rb', line 17 optional :recipients, -> { SignwellSDK::Internal::Type::ArrayOf[SignwellSDK::V1::DocumentRemindParams::Recipient] } |