Class: SignwellSDK::Models::V1::DocumentRetrieveCompletedPdfParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SignwellSDK::Models::V1::DocumentRetrieveCompletedPdfParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/signwell_sdk/models/v1/document_retrieve_completed_pdf_params.rb
Overview
Defined Under Namespace
Modules: FileFormat
Instance Attribute Summary collapse
-
#audit_page ⇒ Boolean?
Whether to include the audit page as part of the document.
-
#file_format ⇒ Symbol, ...
Format of the file to be downloaded.
-
#url_only ⇒ Boolean?
Whether to return the URL of the completed PDF or the actual PDF content.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(audit_page: nil, file_format: nil, url_only: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see DocumentRetrieveCompletedPdfParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(audit_page: nil, file_format: nil, url_only: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see SignwellSDK::Models::V1::DocumentRetrieveCompletedPdfParams for more details.
|
|
# File 'lib/signwell_sdk/models/v1/document_retrieve_completed_pdf_params.rb', line 30
|
Instance Attribute Details
#audit_page ⇒ Boolean?
Whether to include the audit page as part of the document. Defaults to ‘true`
15 |
# File 'lib/signwell_sdk/models/v1/document_retrieve_completed_pdf_params.rb', line 15 optional :audit_page, SignwellSDK::Internal::Type::Boolean |
#file_format ⇒ Symbol, ...
Format of the file to be downloaded. Supported formats are ‘pdf’ and ‘zip’.
21 |
# File 'lib/signwell_sdk/models/v1/document_retrieve_completed_pdf_params.rb', line 21 optional :file_format, enum: -> { SignwellSDK::V1::DocumentRetrieveCompletedPdfParams::FileFormat } |
#url_only ⇒ Boolean?
Whether to return the URL of the completed PDF or the actual PDF content. Defaults to ‘false`.
28 |
# File 'lib/signwell_sdk/models/v1/document_retrieve_completed_pdf_params.rb', line 28 optional :url_only, SignwellSDK::Internal::Type::Boolean |