Class: SignwellSDK::Models::V1::DocumentSendParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SignwellSDK::Models::V1::DocumentSendParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/signwell_sdk/models/v1/document_send_params.rb
Overview
Instance Attribute Summary collapse
-
#allow_decline ⇒ Boolean?
Whether to allow recipients the option to decline signing a document.
-
#allow_reassign ⇒ Boolean?
In some cases a signer is not the right person to sign and may need to reassign their signing responsibilities to another person.
-
#api_application_id ⇒ String?
Unique identifier for API Application settings to use.
-
#apply_signing_order ⇒ Boolean?
When set to ‘true` recipients will sign one at a time in the order of the `recipients` collection of this request.
-
#checkbox_groups ⇒ Array<SignwellSDK::Models::V1::CheckboxGroup>?
Checkbox fields that are placed on a document can be grouped with selection requirements.
-
#custom_requester_email ⇒ String?
Sets the custom requester email for the document.
-
#custom_requester_name ⇒ String?
Sets the custom requester name for the document.
-
#decline_redirect_url ⇒ String?
A URL that recipients are redirected to if the document is declined.
-
#embedded_signing ⇒ Boolean?
When set to ‘true` it enables embedded signing in your website/web application.
-
#embedded_signing_notifications ⇒ Boolean?
On embedding signing, document owners (and CC’d contacts) do not get a notification email when documents have been completed.
-
#expires_in ⇒ Integer?
Number of days before the signature request expires.
-
#labels ⇒ Array<SignwellSDK::Models::V1::Label>?
Labels can be used to organize documents in a way that can make it easy to find using the document search in SignWell.
-
#message ⇒ String?
Email message for the signature request that recipients will see.
-
#metadata ⇒ Hash{Symbol=>String}?
Optional key-value data that can be associated with the document.
-
#name ⇒ String?
The name of the document.
-
#redirect_url ⇒ String?
A URL that recipients are redirected to after successfully signing a document.
-
#reminders ⇒ Boolean?
Whether to send signing reminders to recipients.
-
#subject ⇒ String?
Email subject for the signature request that recipients will see.
-
#test_mode ⇒ Boolean?
Set to ‘true` to enable Test Mode.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(allow_decline: nil, allow_reassign: nil, api_application_id: nil, apply_signing_order: nil, checkbox_groups: nil, custom_requester_email: nil, custom_requester_name: nil, decline_redirect_url: nil, embedded_signing: nil, embedded_signing_notifications: nil, expires_in: nil, labels: nil, message: nil, metadata: nil, name: nil, redirect_url: nil, reminders: nil, subject: nil, test_mode: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see DocumentSendParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(allow_decline: nil, allow_reassign: nil, api_application_id: nil, apply_signing_order: nil, checkbox_groups: nil, custom_requester_email: nil, custom_requester_name: nil, decline_redirect_url: nil, embedded_signing: nil, embedded_signing_notifications: nil, expires_in: nil, labels: nil, message: nil, metadata: nil, name: nil, redirect_url: nil, reminders: nil, subject: nil, test_mode: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see SignwellSDK::Models::V1::DocumentSendParams for more details.
|
|
# File 'lib/signwell_sdk/models/v1/document_send_params.rb', line 152
|
Instance Attribute Details
#allow_decline ⇒ Boolean?
Whether to allow recipients the option to decline signing a document. If multiple signers are involved in a document, any single recipient can cancel the entire document signing process by declining to sign.
17 |
# File 'lib/signwell_sdk/models/v1/document_send_params.rb', line 17 optional :allow_decline, SignwellSDK::Internal::Type::Boolean |
#allow_reassign ⇒ Boolean?
In some cases a signer is not the right person to sign and may need to reassign their signing responsibilities to another person. This feature allows them to reassign the document to someone else.
25 |
# File 'lib/signwell_sdk/models/v1/document_send_params.rb', line 25 optional :allow_reassign, SignwellSDK::Internal::Type::Boolean |
#api_application_id ⇒ String?
Unique identifier for API Application settings to use. API Applications are optional and mainly used when isolating OAuth apps or for more control over embedded API settings
33 |
# File 'lib/signwell_sdk/models/v1/document_send_params.rb', line 33 optional :api_application_id, String |
#apply_signing_order ⇒ Boolean?
When set to ‘true` recipients will sign one at a time in the order of the `recipients` collection of this request.
40 |
# File 'lib/signwell_sdk/models/v1/document_send_params.rb', line 40 optional :apply_signing_order, SignwellSDK::Internal::Type::Boolean |
#checkbox_groups ⇒ Array<SignwellSDK::Models::V1::CheckboxGroup>?
Checkbox fields that are placed on a document can be grouped with selection requirements. At least 2 checkbox fields in an array of fields must be assigned to the same recipient.
48 |
# File 'lib/signwell_sdk/models/v1/document_send_params.rb', line 48 optional :checkbox_groups, -> { SignwellSDK::Internal::Type::ArrayOf[SignwellSDK::V1::CheckboxGroup] } |
#custom_requester_email ⇒ String?
Sets the custom requester email for the document. When set, this is the email used for all email communications, signing notifications, and in the audit file.
55 |
# File 'lib/signwell_sdk/models/v1/document_send_params.rb', line 55 optional :custom_requester_email, String |
#custom_requester_name ⇒ String?
Sets the custom requester name for the document. When set, this is the name used for all email communications, signing notifications, and in the audit file.
62 |
# File 'lib/signwell_sdk/models/v1/document_send_params.rb', line 62 optional :custom_requester_name, String |
#decline_redirect_url ⇒ String?
A URL that recipients are redirected to if the document is declined.
68 |
# File 'lib/signwell_sdk/models/v1/document_send_params.rb', line 68 optional :decline_redirect_url, String |
#embedded_signing ⇒ Boolean?
When set to ‘true` it enables embedded signing in your website/web application. Embedded functionality works with an iFrame and email authentication is disabled. :embedded_signinig defaults to `false`.
76 |
# File 'lib/signwell_sdk/models/v1/document_send_params.rb', line 76 optional :embedded_signing, SignwellSDK::Internal::Type::Boolean |
#embedded_signing_notifications ⇒ Boolean?
On embedding signing, document owners (and CC’d contacts) do not get a notification email when documents have been completed. Setting this param to ‘true` will send out those final completed notifications. Default is `false`
84 |
# File 'lib/signwell_sdk/models/v1/document_send_params.rb', line 84 optional :embedded_signing_notifications, SignwellSDK::Internal::Type::Boolean |
#expires_in ⇒ Integer?
Number of days before the signature request expires. Defaults to the account expiration setting or template expiration (if the document is created from a template).
92 |
# File 'lib/signwell_sdk/models/v1/document_send_params.rb', line 92 optional :expires_in, Integer |
#labels ⇒ Array<SignwellSDK::Models::V1::Label>?
Labels can be used to organize documents in a way that can make it easy to find using the document search in SignWell. A document can have multiple labels. Updating labels on a document will replace any existing labels for that document.
101 |
# File 'lib/signwell_sdk/models/v1/document_send_params.rb', line 101 optional :labels, -> { SignwellSDK::Internal::Type::ArrayOf[SignwellSDK::V1::Label] } |
#message ⇒ String?
Email message for the signature request that recipients will see. Defaults to the default system message or a template message (if the document is created from a template).
109 |
# File 'lib/signwell_sdk/models/v1/document_send_params.rb', line 109 optional :message, String |
#metadata ⇒ Hash{Symbol=>String}?
Optional key-value data that can be associated with the document. If set, will be available every time the document data is returned.
116 |
# File 'lib/signwell_sdk/models/v1/document_send_params.rb', line 116 optional :metadata, SignwellSDK::Internal::Type::HashOf[String] |
#name ⇒ String?
The name of the document.
122 |
# File 'lib/signwell_sdk/models/v1/document_send_params.rb', line 122 optional :name, String |
#redirect_url ⇒ String?
A URL that recipients are redirected to after successfully signing a document.
128 |
# File 'lib/signwell_sdk/models/v1/document_send_params.rb', line 128 optional :redirect_url, String |
#reminders ⇒ Boolean?
Whether to send signing reminders to recipients. Reminders are sent on day 3, day 6, and day 10 if set to ‘true`. Defaults to `true`.
135 |
# File 'lib/signwell_sdk/models/v1/document_send_params.rb', line 135 optional :reminders, SignwellSDK::Internal::Type::Boolean |
#subject ⇒ String?
Email subject for the signature request that recipients will see. Defaults to the default system subject or a template subject (if the document is created from a template).
143 |
# File 'lib/signwell_sdk/models/v1/document_send_params.rb', line 143 optional :subject, String |
#test_mode ⇒ Boolean?
Set to ‘true` to enable Test Mode. Documents created with Test Mode do not count towards API billing and are not legally binding. Defaults to `false`
150 |
# File 'lib/signwell_sdk/models/v1/document_send_params.rb', line 150 optional :test_mode, SignwellSDK::Internal::Type::Boolean |