Class: SignwellSDK::Models::V1::DocumentTemplateCreateParams::Placeholder
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SignwellSDK::Models::V1::DocumentTemplateCreateParams::Placeholder
- Defined in:
- lib/signwell_sdk/models/v1/document_template_create_params.rb
Instance Attribute Summary collapse
-
#id ⇒ String
A unique identifier that you will give to each placeholder.
-
#name ⇒ String
Name of the placeholder.
-
#preassigned_recipient_email ⇒ String?
In some cases, it may be necessary to pre-fill the name and email for a placeholder because it will always be the same person for all documents created from this template.
-
#preassigned_recipient_name ⇒ String?
In some cases, it may be necessary to pre-fill the name and email for a placeholder because it will always be the same person for all documents created from this template.
Instance Method Summary collapse
-
#initialize(files:, placeholders:, allow_decline: nil, allow_reassign: nil, api_application_id: nil, apply_signing_order: nil, attachment_requests: nil, checkbox_groups: nil, copied_placeholders: nil, decline_redirect_url: nil, draft: nil, expires_in: nil, fields: nil, labels: nil, language: nil, message: nil, metadata: nil, name: nil, redirect_url: nil, reminders: nil, subject: nil, text_tags: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see SignwellSDK::Models::V1::DocumentTemplateCreateParams for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(files:, placeholders:, allow_decline: nil, allow_reassign: nil, api_application_id: nil, apply_signing_order: nil, attachment_requests: nil, checkbox_groups: nil, copied_placeholders: nil, decline_redirect_url: nil, draft: nil, expires_in: nil, fields: nil, labels: nil, language: nil, message: nil, metadata: nil, name: nil, redirect_url: nil, reminders: nil, subject: nil, text_tags: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see SignwellSDK::Models::V1::DocumentTemplateCreateParams for more details.
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 239 class Placeholder < SignwellSDK::Internal::Type::BaseModel # @!attribute id # A unique identifier that you will give to each placeholder. We recommend # numbering sequentially from 1 to X. IDs are required for associating recipients # to fields and more. # # @return [String] required :id, String # @!attribute name # Name of the placeholder. # # @return [String] required :name, String # @!attribute preassigned_recipient_email # In some cases, it may be necessary to pre-fill the name and email for a # placeholder because it will always be the same person for all documents created # from this template. This sets the email. # # @return [String, nil] optional :preassigned_recipient_email, String # @!attribute preassigned_recipient_name # In some cases, it may be necessary to pre-fill the name and email for a # placeholder because it will always be the same person for all documents created # from this template. This sets the name. # # @return [String, nil] optional :preassigned_recipient_name, String # @!method initialize(id:, name:, preassigned_recipient_email: nil, preassigned_recipient_name: nil) # Some parameter documentations has been truncated, see # {SignwellSDK::Models::V1::DocumentTemplateCreateParams::Placeholder} for more # details. # # @param id [String] A unique identifier that you will give to each placeholder. We recommend numberi # # @param name [String] Name of the placeholder. # # @param preassigned_recipient_email [String] In some cases, it may be necessary to pre-fill the name and email for a placehol # # @param preassigned_recipient_name [String] In some cases, it may be necessary to pre-fill the name and email for a placehol end |
Instance Attribute Details
#id ⇒ String
A unique identifier that you will give to each placeholder. We recommend numbering sequentially from 1 to X. IDs are required for associating recipients to fields and more.
246 |
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 246 required :id, String |
#name ⇒ String
Name of the placeholder.
252 |
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 252 required :name, String |
#preassigned_recipient_email ⇒ String?
In some cases, it may be necessary to pre-fill the name and email for a placeholder because it will always be the same person for all documents created from this template. This sets the email.
260 |
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 260 optional :preassigned_recipient_email, String |
#preassigned_recipient_name ⇒ String?
In some cases, it may be necessary to pre-fill the name and email for a placeholder because it will always be the same person for all documents created from this template. This sets the name.
268 |
# File 'lib/signwell_sdk/models/v1/document_template_create_params.rb', line 268 optional :preassigned_recipient_name, String |