Class: SignwellSDK::Models::V1::DocumentTemplateUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SignwellSDK::Models::V1::DocumentTemplateUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/signwell_sdk/models/v1/document_template_update_params.rb
Overview
Instance Attribute Summary collapse
-
#allow_decline ⇒ Boolean?
Whether to allow recipients the option to decline signing a document.
-
#allow_reassign ⇒ Boolean?
In some cases a signer is not the right person to sign and may need to reassign their signing responsibilities to another person.
-
#api_application_id ⇒ String?
Unique identifier for API Application settings to use.
-
#apply_signing_order ⇒ Boolean?
When set to ‘true` recipients will sign one at a time in the order of the `recipients` collection of this request.
-
#checkbox_groups ⇒ Array<SignwellSDK::Models::V1::TemplateCheckboxGroup>?
Checkbox fields that are placed on a document can be grouped with selection requirements.
-
#decline_redirect_url ⇒ String?
A URL that recipients are redirected to if the document is declined.
-
#draft ⇒ Boolean?
Whether the template can still be updated before it is ready for usage.
-
#expires_in ⇒ Integer?
Number of days before the signature request expires.
-
#labels ⇒ Array<SignwellSDK::Models::V1::Label>?
Labels can be used to organize documents in a way that can make it easy to find using the document search in SignWell.
-
#message ⇒ String?
Email message for the signature request that recipients will see.
-
#metadata ⇒ Hash{Symbol=>String}?
Optional key-value data that can be associated with the document.
-
#name ⇒ String?
The name of the template.
-
#redirect_url ⇒ String?
A URL that recipients are redirected to after successfully signing a document.
-
#reminders ⇒ Boolean?
Whether to send signing reminders to recipients.
-
#subject ⇒ String?
Email subject for the signature request that recipients will see.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(allow_decline: nil, allow_reassign: nil, api_application_id: nil, apply_signing_order: nil, checkbox_groups: nil, decline_redirect_url: nil, draft: nil, expires_in: nil, labels: nil, message: nil, metadata: nil, name: nil, redirect_url: nil, reminders: nil, subject: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see DocumentTemplateUpdateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(allow_decline: nil, allow_reassign: nil, api_application_id: nil, apply_signing_order: nil, checkbox_groups: nil, decline_redirect_url: nil, draft: nil, expires_in: nil, labels: nil, message: nil, metadata: nil, name: nil, redirect_url: nil, reminders: nil, subject: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see SignwellSDK::Models::V1::DocumentTemplateUpdateParams for more details.
|
|
# File 'lib/signwell_sdk/models/v1/document_template_update_params.rb', line 124
|
Instance Attribute Details
#allow_decline ⇒ Boolean?
Whether to allow recipients the option to decline signing a document. If multiple signers are involved in a document, any single recipient can cancel the entire document signing process by declining to sign.
17 |
# File 'lib/signwell_sdk/models/v1/document_template_update_params.rb', line 17 optional :allow_decline, SignwellSDK::Internal::Type::Boolean |
#allow_reassign ⇒ Boolean?
In some cases a signer is not the right person to sign and may need to reassign their signing responsibilities to another person. This feature allows them to reassign the document to someone else.
25 |
# File 'lib/signwell_sdk/models/v1/document_template_update_params.rb', line 25 optional :allow_reassign, SignwellSDK::Internal::Type::Boolean |
#api_application_id ⇒ String?
Unique identifier for API Application settings to use. API Applications are optional and mainly used when isolating OAuth apps or for more control over embedded API settings
33 |
# File 'lib/signwell_sdk/models/v1/document_template_update_params.rb', line 33 optional :api_application_id, String |
#apply_signing_order ⇒ Boolean?
When set to ‘true` recipients will sign one at a time in the order of the `recipients` collection of this request.
40 |
# File 'lib/signwell_sdk/models/v1/document_template_update_params.rb', line 40 optional :apply_signing_order, SignwellSDK::Internal::Type::Boolean |
#checkbox_groups ⇒ Array<SignwellSDK::Models::V1::TemplateCheckboxGroup>?
Checkbox fields that are placed on a document can be grouped with selection requirements. At least 2 checkbox fields in an array of fields must be assigned to the same recipient.
48 49 |
# File 'lib/signwell_sdk/models/v1/document_template_update_params.rb', line 48 optional :checkbox_groups, -> { SignwellSDK::Internal::Type::ArrayOf[SignwellSDK::V1::TemplateCheckboxGroup] } |
#decline_redirect_url ⇒ String?
A URL that recipients are redirected to if the document is declined.
55 |
# File 'lib/signwell_sdk/models/v1/document_template_update_params.rb', line 55 optional :decline_redirect_url, String |
#draft ⇒ Boolean?
Whether the template can still be updated before it is ready for usage. If set to ‘false` the template is marked as `Available` and it will be ready for use. Defaults to `false`.
63 |
# File 'lib/signwell_sdk/models/v1/document_template_update_params.rb', line 63 optional :draft, SignwellSDK::Internal::Type::Boolean |
#expires_in ⇒ Integer?
Number of days before the signature request expires. Defaults to the account expiration setting or template expiration (if the document is created from a template).
71 |
# File 'lib/signwell_sdk/models/v1/document_template_update_params.rb', line 71 optional :expires_in, Integer |
#labels ⇒ Array<SignwellSDK::Models::V1::Label>?
Labels can be used to organize documents in a way that can make it easy to find using the document search in SignWell. A document can have multiple labels. Updating labels on a document will replace any existing labels for that document.
80 |
# File 'lib/signwell_sdk/models/v1/document_template_update_params.rb', line 80 optional :labels, -> { SignwellSDK::Internal::Type::ArrayOf[SignwellSDK::V1::Label] } |
#message ⇒ String?
Email message for the signature request that recipients will see. Defaults to the default system message or a template message (if the document is created from a template).
88 |
# File 'lib/signwell_sdk/models/v1/document_template_update_params.rb', line 88 optional :message, String |
#metadata ⇒ Hash{Symbol=>String}?
Optional key-value data that can be associated with the document. If set, will be available every time the document data is returned.
95 |
# File 'lib/signwell_sdk/models/v1/document_template_update_params.rb', line 95 optional :metadata, SignwellSDK::Internal::Type::HashOf[String] |
#name ⇒ String?
The name of the template.
101 |
# File 'lib/signwell_sdk/models/v1/document_template_update_params.rb', line 101 optional :name, String |
#redirect_url ⇒ String?
A URL that recipients are redirected to after successfully signing a document.
107 |
# File 'lib/signwell_sdk/models/v1/document_template_update_params.rb', line 107 optional :redirect_url, String |
#reminders ⇒ Boolean?
Whether to send signing reminders to recipients. Reminders are sent on day 3, day 6, and day 10 if set to ‘true`. Defaults to `true`.
114 |
# File 'lib/signwell_sdk/models/v1/document_template_update_params.rb', line 114 optional :reminders, SignwellSDK::Internal::Type::Boolean |
#subject ⇒ String?
Email subject for the signature request that recipients will see. Defaults to the default system subject or a template subject (if the document is created from a template).
122 |
# File 'lib/signwell_sdk/models/v1/document_template_update_params.rb', line 122 optional :subject, String |