Class: SignwellSDK::Models::V1::Label
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SignwellSDK::Models::V1::Label
- Defined in:
- lib/signwell_sdk/models/v1/label.rb
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(name:) ⇒ Object
constructor
Labels can be used to organize documents and templates in a way that can make it easy to find using the document search/template search in SignWell.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:) ⇒ Object
Labels can be used to organize documents and templates in a way that can make it easy to find using the document search/template search in SignWell. Labels can be used to organize documents in a way that can make it easy to find using the document search in SignWell.
|
|
# File 'lib/signwell_sdk/models/v1/label.rb', line 12
|
Instance Attribute Details
#name ⇒ String
10 |
# File 'lib/signwell_sdk/models/v1/label.rb', line 10 required :name, String |