Class: SignwellSDK::Resources::V1::Documents
- Inherits:
-
Object
- Object
- SignwellSDK::Resources::V1::Documents
- Defined in:
- lib/signwell_sdk/resources/v1/documents.rb
Instance Method Summary collapse
-
#create(files:, recipients:, allow_decline: nil, allow_reassign: nil, api_application_id: nil, apply_signing_order: nil, attachment_requests: nil, checkbox_groups: nil, copied_contacts: nil, custom_requester_email: nil, custom_requester_name: nil, decline_redirect_url: nil, draft: nil, embedded_signing: nil, embedded_signing_notifications: nil, expires_in: nil, fields: nil, labels: nil, language: nil, message: nil, metadata: nil, name: nil, redirect_url: nil, reminders: nil, subject: nil, test_mode: nil, text_tags: nil, with_signature_page: nil, request_options: {}) ⇒ SignwellSDK::Models::V1::Document
Some parameter documentations has been truncated, see Models::V1::DocumentCreateParams for more details.
-
#create_from_template(recipients:, allow_decline: nil, allow_reassign: nil, api_application_id: nil, apply_signing_order: nil, attachment_requests: nil, checkbox_groups: nil, copied_contacts: nil, custom_requester_email: nil, custom_requester_name: nil, decline_redirect_url: nil, draft: nil, embedded_signing: nil, embedded_signing_notifications: nil, expires_in: nil, fields: nil, files: nil, labels: nil, language: nil, message: nil, metadata: nil, name: nil, redirect_url: nil, reminders: nil, subject: nil, template_fields: nil, template_id: nil, template_ids: nil, test_mode: nil, text_tags: nil, with_signature_page: nil, request_options: {}) ⇒ SignwellSDK::Models::V1::DocumentCreateFromTemplateResponse
Some parameter documentations has been truncated, see Models::V1::DocumentCreateFromTemplateParams for more details.
-
#delete(id, request_options: {}) ⇒ nil
Deletes a document.
-
#initialize(client:) ⇒ Documents
constructor
private
A new instance of Documents.
-
#list(limit: nil, page: nil, request_options: {}) ⇒ SignwellSDK::Models::V1::DocumentListResponse
Returns a paginated list of documents for the authenticated account.
-
#remind(id, recipients: nil, request_options: {}) ⇒ nil
Some parameter documentations has been truncated, see Models::V1::DocumentRemindParams for more details.
-
#retrieve(id, request_options: {}) ⇒ SignwellSDK::Models::V1::Document
Returns a document and all associated document data.
-
#retrieve_completed_pdf(id, audit_page: nil, file_format: nil, url_only: nil, request_options: {}) ⇒ SignwellSDK::Models::V1::DocumentRetrieveCompletedPdfResponse
Some parameter documentations has been truncated, see Models::V1::DocumentRetrieveCompletedPdfParams for more details.
-
#send_(id, allow_decline: nil, allow_reassign: nil, api_application_id: nil, apply_signing_order: nil, checkbox_groups: nil, custom_requester_email: nil, custom_requester_name: nil, decline_redirect_url: nil, embedded_signing: nil, embedded_signing_notifications: nil, expires_in: nil, labels: nil, message: nil, metadata: nil, name: nil, redirect_url: nil, reminders: nil, subject: nil, test_mode: nil, request_options: {}) ⇒ SignwellSDK::Models::V1::Document
Some parameter documentations has been truncated, see Models::V1::DocumentSendParams for more details.
Constructor Details
#initialize(client:) ⇒ Documents
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Documents.
366 367 368 |
# File 'lib/signwell_sdk/resources/v1/documents.rb', line 366 def initialize(client:) @client = client end |
Instance Method Details
#create(files:, recipients:, allow_decline: nil, allow_reassign: nil, api_application_id: nil, apply_signing_order: nil, attachment_requests: nil, checkbox_groups: nil, copied_contacts: nil, custom_requester_email: nil, custom_requester_name: nil, decline_redirect_url: nil, draft: nil, embedded_signing: nil, embedded_signing_notifications: nil, expires_in: nil, fields: nil, labels: nil, language: nil, message: nil, metadata: nil, name: nil, redirect_url: nil, reminders: nil, subject: nil, test_mode: nil, text_tags: nil, with_signature_page: nil, request_options: {}) ⇒ SignwellSDK::Models::V1::Document
Some parameter documentations has been truncated, see Models::V1::DocumentCreateParams for more details.
Creates and optionally sends a new document for signing. If ‘draft` is set to true the document will not be sent.
76 77 78 79 80 81 82 83 84 85 |
# File 'lib/signwell_sdk/resources/v1/documents.rb', line 76 def create(params) parsed, = SignwellSDK::V1::DocumentCreateParams.dump_request(params) @client.request( method: :post, path: "api/v1/documents", body: parsed, model: SignwellSDK::V1::Document, options: ) end |
#create_from_template(recipients:, allow_decline: nil, allow_reassign: nil, api_application_id: nil, apply_signing_order: nil, attachment_requests: nil, checkbox_groups: nil, copied_contacts: nil, custom_requester_email: nil, custom_requester_name: nil, decline_redirect_url: nil, draft: nil, embedded_signing: nil, embedded_signing_notifications: nil, expires_in: nil, fields: nil, files: nil, labels: nil, language: nil, message: nil, metadata: nil, name: nil, redirect_url: nil, reminders: nil, subject: nil, template_fields: nil, template_id: nil, template_ids: nil, test_mode: nil, text_tags: nil, with_signature_page: nil, request_options: {}) ⇒ SignwellSDK::Models::V1::DocumentCreateFromTemplateResponse
Some parameter documentations has been truncated, see Models::V1::DocumentCreateFromTemplateParams for more details.
Creates and optionally sends a new document for signing. If ‘draft` is set to true the document will not be sent.
:template_
230 231 232 233 234 235 236 237 238 239 |
# File 'lib/signwell_sdk/resources/v1/documents.rb', line 230 def create_from_template(params) parsed, = SignwellSDK::V1::DocumentCreateFromTemplateParams.dump_request(params) @client.request( method: :post, path: "api/v1/document_templates/documents", body: parsed, model: SignwellSDK::Models::V1::DocumentCreateFromTemplateResponse, options: ) end |
#delete(id, request_options: {}) ⇒ nil
Deletes a document. Deleting a document will also cancel document signing (if in progress). Supply the unique document ID from either a Create Document request or document page URL.
145 146 147 148 149 150 151 152 |
# File 'lib/signwell_sdk/resources/v1/documents.rb', line 145 def delete(id, params = {}) @client.request( method: :delete, path: ["api/v1/documents/%1$s", id], model: NilClass, options: params[:request_options] ) end |
#list(limit: nil, page: nil, request_options: {}) ⇒ SignwellSDK::Models::V1::DocumentListResponse
Returns a paginated list of documents for the authenticated account.
121 122 123 124 125 126 127 128 129 130 |
# File 'lib/signwell_sdk/resources/v1/documents.rb', line 121 def list(params = {}) parsed, = SignwellSDK::V1::DocumentListParams.dump_request(params) @client.request( method: :get, path: "api/v1/documents", query: parsed, model: SignwellSDK::Models::V1::DocumentListResponse, options: ) end |
#remind(id, recipients: nil, request_options: {}) ⇒ nil
Some parameter documentations has been truncated, see Models::V1::DocumentRemindParams for more details.
Sends a reminder email to recipients that have not signed yet.
257 258 259 260 261 262 263 264 265 266 |
# File 'lib/signwell_sdk/resources/v1/documents.rb', line 257 def remind(id, params = {}) parsed, = SignwellSDK::V1::DocumentRemindParams.dump_request(params) @client.request( method: :post, path: ["api/v1/documents/%1$s/remind", id], body: parsed, model: NilClass, options: ) end |
#retrieve(id, request_options: {}) ⇒ SignwellSDK::Models::V1::Document
Returns a document and all associated document data. Supply the unique document ID from either a document creation request or Document page URL.
99 100 101 102 103 104 105 106 |
# File 'lib/signwell_sdk/resources/v1/documents.rb', line 99 def retrieve(id, params = {}) @client.request( method: :get, path: ["api/v1/documents/%1$s", id], model: SignwellSDK::V1::Document, options: params[:request_options] ) end |
#retrieve_completed_pdf(id, audit_page: nil, file_format: nil, url_only: nil, request_options: {}) ⇒ SignwellSDK::Models::V1::DocumentRetrieveCompletedPdfResponse
Some parameter documentations has been truncated, see Models::V1::DocumentRetrieveCompletedPdfParams for more details.
Gets a completed document PDF or ZIP file. Supply the unique document ID from either a document creation request or document page URL.
289 290 291 292 293 294 295 296 297 298 |
# File 'lib/signwell_sdk/resources/v1/documents.rb', line 289 def retrieve_completed_pdf(id, params = {}) parsed, = SignwellSDK::V1::DocumentRetrieveCompletedPdfParams.dump_request(params) @client.request( method: :get, path: ["api/v1/documents/%1$s/completed_pdf", id], query: parsed, model: SignwellSDK::Models::V1::DocumentRetrieveCompletedPdfResponse, options: ) end |
#send_(id, allow_decline: nil, allow_reassign: nil, api_application_id: nil, apply_signing_order: nil, checkbox_groups: nil, custom_requester_email: nil, custom_requester_name: nil, decline_redirect_url: nil, embedded_signing: nil, embedded_signing_notifications: nil, expires_in: nil, labels: nil, message: nil, metadata: nil, name: nil, redirect_url: nil, reminders: nil, subject: nil, test_mode: nil, request_options: {}) ⇒ SignwellSDK::Models::V1::Document
Some parameter documentations has been truncated, see Models::V1::DocumentSendParams for more details.
Updates a draft document and sends it to be signed by recipients.
352 353 354 355 356 357 358 359 360 361 |
# File 'lib/signwell_sdk/resources/v1/documents.rb', line 352 def send_(id, params = {}) parsed, = SignwellSDK::V1::DocumentSendParams.dump_request(params) @client.request( method: :post, path: ["api/v1/documents/%1$s/send", id], body: parsed, model: SignwellSDK::V1::Document, options: ) end |